AUGraphAddRenderNotify

Function AUGraphAddRenderNotify 

pub unsafe extern "C-unwind" fn AUGraphAddRenderNotify(
    in_graph: AUGraph,
    in_callback: AURenderCallback,
    in_ref_con: *mut c_void,
) -> i32
👎Deprecated: AUGraph is deprecated in favor of AVAudioEngine
Available on crate features AUComponent and AUGraph and objc2-core-audio-types only.
Add a notification callback

Add a callback that the graph will call every time the graph renders. The callback will be called once before the graph’s render operation, and once after the render operation is complete.

Safety

  • in_graph must be a valid pointer.
  • in_callback must be implemented correctly.
  • in_ref_con must be a valid pointer or null.