AUGraphDisconnectNodeInput

Function AUGraphDisconnectNodeInput 

pub unsafe extern "C-unwind" fn AUGraphDisconnectNodeInput(
    in_graph: AUGraph,
    in_dest_node: AUNode,
    in_dest_input_number: u32,
) -> i32
👎Deprecated: AUGraph is deprecated in favor of AVAudioEngine
Available on crate feature AUGraph only.
disconnect a node’s input

This can be used to disconnect either a connection or callback interaction to the specified node input

Safety

in_graph must be a valid pointer.