AUGraphGetMaxCPULoad

Function AUGraphGetMaxCPULoad 

pub unsafe extern "C-unwind" fn AUGraphGetMaxCPULoad(
    in_graph: AUGraph,
    out_max_load: NonNull<f32>,
) -> i32
๐Ÿ‘ŽDeprecated: AUGraph is deprecated in favor of AVAudioEngine
Available on crate feature AUGraph only.
The Maximum CPU load of the graph

Returns the max CPU load of the graph since this call was last made or the graph was last started.

Safety

  • in_graph must be a valid pointer.
  • out_max_load must be a valid pointer.