pub unsafe extern "C-unwind" fn AUGraphIsNodeSubGraph(
in_graph: AUGraph,
in_node: AUNode,
out_flag: NonNull<u8>,
) -> i32๐Deprecated: no longer supported
Available on crate feature
AUGraph only.Expand description
Determine whether the node represents a sub graph
This will return true if the specified node represents a subgraph, false if not.
Parameter inGraph: the AUGraph object
Parameter inNode: the node to query
Parameter outFlag: true if the node is a subgraph, false if not
Safety
in_graphmust be a valid pointer.out_flagmust be a valid pointer.