AUGraphNewNodeSubGraph

Function AUGraphNewNodeSubGraph 

pub unsafe extern "C-unwind" fn AUGraphNewNodeSubGraph(
    in_graph: AUGraph,
    out_node: NonNull<AUNode>,
) -> i32
๐Ÿ‘ŽDeprecated: no longer supported
Available on crate feature AUGraph only.
Create a node that will represent a sub graph

This will create a node that represents a contained or member AUGraph. The AUGraph can be retrieved through the GetNodeInfoSubGraph call. The member AUGraph is owned by the parent graph and will be disposed when either:

  1. The parent graph is disposed
  2. The node is removed from the parent AUGraph

Parameter inGraph: the AUGraph object

Parameter outNode: the node that is used to refer to the sub-graph

Safety

  • in_graph must be a valid pointer.
  • out_node must be a valid pointer.