AUGraphRemoveRenderNotify

Function AUGraphRemoveRenderNotify 

pub unsafe extern "C-unwind" fn AUGraphRemoveRenderNotify(
    in_graph: AUGraph,
    in_callback: AURenderCallback,
    in_ref_con: *mut c_void,
) -> i32
๐Ÿ‘ŽDeprecated: AUGraph is deprecated in favor of AVAudioEngine
Available on crate features AUComponent and AUGraph and objc2-core-audio-types only.
Remove a notification callback

Remove a previously added callback. You must provide both the callback and the refCon that was used previously to add the callback.

Safety

  • in_graph must be a valid pointer.
  • in_callback must be implemented correctly.
  • in_ref_con must be a valid pointer or null.