pub unsafe extern "C-unwind" fn AUParameterValueToLinear(
in_parameter_value: AudioUnitParameterValue,
in_parameter: NonNull<AudioUnitParameter>,
) -> f32Available on crate features
AUComponent and AudioComponent and AudioUnitUtilities only.Expand description
Converts a parameter value to a linear value according to the parameter’s units.
Parameter inParameterValue: The value in the natural units of the specified parameter.
Parameter inParameter: The parameter, including its Audio Unit, that will define the conversion of
the supplied parameter value to a corresponding linear value.
Returns: A number 0.0-1.0.
Safety
in_parameter must be a valid pointer.