pub unsafe extern "C-unwind" fn AudioCodecUninitialize(
in_codec: AudioCodec,
) -> i32Available on crate features
AudioCodec and AudioComponent only.Expand description
This call will move the codec from the initialized state back to the uninitialized state. The codec will release any resources it allocated or claimed in AudioCodecInitialize.
Parameter inCodec: An AudioCodec instance
Returns: The OSStatus value
Safety
in_codec must be a valid pointer.