AudioComponentCopyConfigurationInfo

Function AudioComponentCopyConfigurationInfo 

pub unsafe extern "C-unwind" fn AudioComponentCopyConfigurationInfo(
    in_component: AudioComponent,
    out_configuration_info: NonNull<*const CFDictionary>,
) -> i32
Available on crate features AudioComponent and objc2-core-foundation only.
Fetches the basic configuration info about a given AudioComponent

Currently, only AudioUnits can supply this information.

Parameter inComponent: The AudioComponent whose info is being fetched.

Parameter outConfigurationInfo: On exit, this is CFDictionaryRef that contains information describing the capabilities of the AudioComponent. The specific information depends on the type of AudioComponent. The keys for the dictionary are defined in AudioUnitProperties.h (or other headers as appropriate for the component type).

Returns: An OSStatus indicating success or failure.

Safety

  • in_component must be a valid pointer.
  • out_configuration_info must be a valid pointer.