AudioComponentFindNext

Function AudioComponentFindNext 

pub unsafe extern "C-unwind" fn AudioComponentFindNext(
    in_component: AudioComponent,
    in_desc: NonNull<AudioComponentDescription>,
) -> AudioComponent
Available on crate feature AudioComponent only.
Finds an audio component.

This function is used to find an audio component that is the closest match to the provided values. Note that the list of available components may change dynamically in situations involving inter-app audio on iOS, or version 3 audio unit extensions. See kAudioComponentRegistrationsChangedNotification.

Parameter inComponent: If NULL, then the search starts from the beginning until an audio component is found that matches the description provided by inDesc. If non-NULL, then the search starts (continues) from the previously found audio component specified by inComponent, and will return the next found audio component.

Parameter inDesc: The type, subtype and manufacturer fields are used to specify the audio component to search for. A value of 0 (zero) for any of these fields is a wildcard, so the first match found is returned.

Returns: An audio component that matches the search parameters, or NULL if none found.

Safety

  • in_component must be a valid pointer or null.
  • in_desc must be a valid pointer.