pub unsafe extern "C-unwind" fn AudioComponentGetDescription(
in_component: AudioComponent,
out_desc: NonNull<AudioComponentDescription>,
) -> i32Available on crate feature
AudioComponent only.Expand description
Retrieve an audio component’s description.
This will return the fully specified audio component description for the provided audio component.
Parameter inComponent: the audio component (must not be NULL)
Parameter outDesc: the audio component description for the specified audio component
Returns: an OSStatus result code.
Safety
in_componentmust be a valid pointer.out_descmust be a valid pointer.