AudioComponentGetLastActiveTime

Function AudioComponentGetLastActiveTime 

pub unsafe extern "C-unwind" fn AudioComponentGetLastActiveTime(
    comp: AudioComponent,
) -> CFAbsoluteTime
๐Ÿ‘ŽDeprecated: Inter-App Audio API is deprecated in favor of Audio Units
Available on crate features AUComponent and AudioComponent and objc2-core-foundation only.
Fetches the time at which the application publishing the component was last active.

Inter-app audio hosts can use this to sort the list of available nodes by how recently the user interacted with them.

Parameter comp: The AudioComponent being queried.

Returns: The CFAbsoluteTime at which the node was last active (0 if never).

Safety

comp must be a valid pointer.