AudioComponentInstanceDispose

Function AudioComponentInstanceDispose 

pub unsafe extern "C-unwind" fn AudioComponentInstanceDispose(
    in_instance: AudioComponentInstance,
) -> i32
Available on crate feature AudioComponent only.
Disposes of an audio component instance.

This function will dispose the audio component instance that was created with the New call. It will deallocate any resources that the instance was using.

Parameter inInstance: the audio component instance to dispose (must not be NULL)

Returns: an OSStatus result code.

Safety

in_instance must be a valid pointer.