AudioComponentInstanceGetComponent

Function AudioComponentInstanceGetComponent 

pub unsafe extern "C-unwind" fn AudioComponentInstanceGetComponent(
    in_instance: AudioComponentInstance,
) -> AudioComponent
Available on crate feature AudioComponent only.
Retrieve the audio component from its instance

Allows the application at any time to retrieve the audio component that is the factory object of a given instance (i.e., the audio component that was used to create the instance in the first place). This allows the application to retrieve general information about a particular audio component (its name, version, etc) when one just has an audio component instance to work with

Parameter inInstance: the audio component instance (must not be NULL, and instance must be valid - that is, not disposed)

Returns: a valid audio component or NULL if no component was found.

Safety

in_instance must be a valid pointer.