AudioComponentValidateWithResults

Function AudioComponentValidateWithResults 

pub unsafe extern "C-unwind" fn AudioComponentValidateWithResults(
    in_component: AudioComponent,
    in_validation_parameters: Option<&CFDictionary>,
    in_completion_handler: &DynBlock<dyn Fn(AudioComponentValidationResult, NonNull<CFDictionary>)>,
) -> i32
Available on crate features AudioComponent and block2 and objc2-core-foundation only.
Tests a specified AudioComponent for API and behavioral conformance asynchronously, returning detailed validation results.

Currently, only AudioUnits can can be validated. The inCompletionHandler callback has two parameters, an AudioComponentValidationResult with result of the validation, and a CFDictionaryRef which contains the details of this result. This dictionary may contain the following entries: “Output” An array of strings, with the same content as if the AU was validated on auval. “Result” An AudioComponentValidationResult with the result of the validation process. The same as what’s in the AudioComponentValidationResult in the inCompletionHandler and what AudioComponentValidate currently returns. “Tests” An array in which each value is a dictionary and may contain: “Name” A descriptive name of the test. “Result” An AudioComponentValidationResult with the result of the specific test. “Output” An array of strings with output generated by the test. “WasCached” YES if the returned result was cached from previous runs.

Parameter inComponent: The AudioComponent to validate.

Parameter inValidationParameters: A CFDictionaryRef that contains parameters for the validation operation. Passing NULL for this argument tells the system to use the default parameters.

Parameter inCompletionHandler: Completion callback. See discussion section.

Returns: an OSStatus result code.

Safety

  • in_component must be a valid pointer.
  • in_validation_parameters generics must be of the correct type.