AudioConverterNewWithOptions

Function AudioConverterNewWithOptions 

pub unsafe extern "C-unwind" fn AudioConverterNewWithOptions(
    in_source_format: NonNull<AudioStreamBasicDescription>,
    in_destination_format: NonNull<AudioStreamBasicDescription>,
    in_options: AudioConverterOptions,
    out_audio_converter: NonNull<AudioConverterRef>,
) -> i32
Available on crate features AudioConverter and objc2-core-audio-types only.
Create a new AudioConverter with one or more options enabled.

Parameter inSourceFormat: The format of the source audio to be converted.

Parameter inDestinationFormat: The destination format to which the audio is to be converted.

Parameter inOptions: Flags selecting one or more optional configurations for the AudioConverter.

Parameter outAudioConverter: On successful return, points to a new AudioConverter instance.

Returns: An OSStatus result code.

This is an alternative to AudioConverterNew which supports enabling one or more optional configurations for the new AudioConverter.

Safety

  • in_source_format must be a valid pointer.
  • in_destination_format must be a valid pointer.
  • out_audio_converter must be a valid pointer.