pub unsafe extern "C-unwind" fn AudioFileComponentCountUserData(
in_component: AudioFileComponent,
in_user_data_id: u32,
out_number_items: NonNull<u32>,
) -> i32Available on crate feature
AudioComponent only.Expand description
implements AudioFileCountUserData
“User Data” refers to chunks in AIFF, CAF and WAVE files, or resources in Sound Designer II files, and possibly other things in other files. For simplicity, referred to below as “chunks”.
Parameter inComponent: an AudioFileComponent
Parameter inUserDataID: the four char code of the chunk.
Parameter outNumberItems: on output, if successful, number of chunks of this type in the file.
Returns: returns noErr if successful.
Safety
in_componentmust be a valid pointer.out_number_itemsmust be a valid pointer.