pub unsafe extern "C-unwind" fn AudioFileComponentCreateURL(
in_component: AudioFileComponent,
in_file_ref: &CFURL,
in_format: NonNull<AudioStreamBasicDescription>,
in_flags: u32,
) -> i32Available on crate features
AudioComponent and objc2-core-audio-types and objc2-core-foundation only.Expand description
creates a new (or initialises an existing) audio file specified by the URL.
creates a new (or initialises an existing) audio file specified by the URL.
Parameter inComponent: an AudioFileComponent
Parameter inFileRef: an CFURLRef fully specifying the path of the file to create/initialise
Parameter inFormat: an AudioStreamBasicDescription describing the data format that will be
added to the audio file.
Parameter inFlags: relevant flags for creating/opening the file.
if kAudioFileFlags_EraseFile is set, it will erase an existing file
if not set, then the Create call will fail if the URL is an existing file
Returns: returns noErr if successful.
Safety
in_componentmust be a valid pointer.in_formatmust be a valid pointer.