pub unsafe extern "C-unwind" fn AudioFileComponentDataIsThisFormat(
in_component: AudioFileComponent,
in_client_data: *mut c_void,
in_read_func: AudioFile_ReadProc,
in_write_func: AudioFile_WriteProc,
in_get_size_func: AudioFile_GetSizeProc,
in_set_size_func: AudioFile_SetSizeProc,
out_result: NonNull<u32>,
) -> i32๐Deprecated: no longer supported
Available on crate features
AudioComponent and AudioFile only.Expand description
deprecated. use AudioFileComponentFileDataIsThisFormat instead.
Parameter inComponent: an AudioFileComponent
Parameter inClientData: a constant that will be passed to your callbacks.
Parameter inReadFunc: a function that will be called when AudioFile needs to read data.
Parameter inWriteFunc: a function that will be called when AudioFile needs to write data.
Parameter inGetSizeFunc: a function that will be called when AudioFile needs to know the file size.
Parameter inSetSizeFunc: a function that will be called when AudioFile needs to set the file size.
Parameter outResult: on output, is set to 1 if the file data is recognized by this component, 0 if not.
Returns: returns noErr if successful.
Safety
in_componentmust be a valid pointer.in_client_datamust be a valid pointer or null.in_read_funcmust be implemented correctly.in_write_funcmust be implemented correctly.in_get_size_funcmust be implemented correctly.in_set_size_funcmust be implemented correctly.out_resultmust be a valid pointer.