pub unsafe extern "C-unwind" fn AudioFileComponentExtensionIsThisFormat(
in_component: AudioFileComponent,
in_extension: &CFString,
out_result: NonNull<u32>,
) -> i32Available on crate features
AudioComponent and objc2-core-foundation only.Expand description
used by the AudioFile API to determine if this component is appropriate for handling a file.
Parameter inComponent: an AudioFileComponent
Parameter inExtension: a CFString containing a file name extension.
Parameter outResult: on output, is set to 1 if the extension is recognized by this component, 0 if not.
Returns: returns noErr if successful.
Safety
in_componentmust be a valid pointer.out_resultmust be a valid pointer.