pub unsafe extern "C-unwind" fn AudioFileComponentFileDataIsThisFormat(
in_component: AudioFileComponent,
in_data_byte_size: u32,
in_data: NonNull<c_void>,
out_result: NonNull<u32>,
) -> i32Available on crate feature
AudioComponent only.Expand description
used by the AudioFile API to determine if this component is appropriate for handling a file.
Parameter inComponent: an AudioFileComponent
Parameter inDataByteSize: the size of inData in bytes.
Parameter inData: a pointer to a buffer of audio file data.
Parameter outResult: on output, is set to 1 if the file is recognized by this component, 0 if not.
Returns: returns noErr if successful.
Safety
in_componentmust be a valid pointer.in_datamust be a valid pointer.out_resultmust be a valid pointer.