AudioFileComponentGetGlobalInfo

Function AudioFileComponentGetGlobalInfo 

pub unsafe extern "C-unwind" fn AudioFileComponentGetGlobalInfo(
    in_component: AudioFileComponent,
    in_property_id: AudioFileComponentPropertyID,
    in_specifier_size: u32,
    in_specifier: *const c_void,
    io_property_data_size: NonNull<u32>,
    out_property_data: NonNull<c_void>,
) -> i32
Available on crate feature AudioComponent only.
implements AudioFileGetGlobalInfo.

Parameter inComponent: an AudioFileComponent

Parameter inPropertyID: an AudioFileGlobalInfo property constant.

Parameter inSpecifierSize: The size of the specifier data.

Parameter inSpecifier: A specifier is a buffer of data used as an input argument to some of the global info properties.

Parameter ioPropertyDataSize: on input the size of the outPropertyData buffer. On output the number of bytes written to the buffer.

Parameter outPropertyData: the buffer in which to write the property data.

Returns: returns noErr if successful.

Safety

  • in_component must be a valid pointer.
  • in_specifier must be a valid pointer or null.
  • io_property_data_size must be a valid pointer.
  • out_property_data must be a valid pointer.