AudioFileComponentGetGlobalInfoSize

Function AudioFileComponentGetGlobalInfoSize 

pub unsafe extern "C-unwind" fn AudioFileComponentGetGlobalInfoSize(
    in_component: AudioFileComponent,
    in_property_id: AudioFileComponentPropertyID,
    in_specifier_size: u32,
    in_specifier: *const c_void,
    out_property_size: NonNull<u32>,
) -> i32
Available on crate feature AudioComponent only.
implements AudioFileGetGlobalInfoSize.

Parameter inComponent: an AudioFileComponent

Parameter inPropertyID: an AudioFileGlobalInfo property constant.

Parameter inSpecifierSize: The size of the specifier data.

Parameter inSpecifier: A specifier is a buffer of data used as an input argument to some of the global info properties.

Parameter outPropertySize: the size in bytes of the current value of the property. In order to get the property value, you will need a buffer of this size.

Returns: returns noErr if successful.

Safety

  • in_component must be a valid pointer.
  • in_specifier must be a valid pointer or null.
  • out_property_size must be a valid pointer.