pub unsafe extern "C-unwind" fn AudioFileComponentGetProperty(
in_component: AudioFileComponent,
in_property_id: AudioFileComponentPropertyID,
io_property_data_size: NonNull<u32>,
out_property_data: NonNull<c_void>,
) -> i32Available on crate feature
AudioComponent only.Expand description
implements AudioFileGetProperty.
Parameter inComponent: an AudioFileComponent
Parameter inPropertyID: an AudioFileProperty constant.
Parameter ioPropertyDataSize: on input the size of the outPropertyData buffer. On output the number of bytes written to the buffer.
Parameter outPropertyData: the buffer in which to write the property data.
Returns: returns noErr if successful.
Safety
in_componentmust be a valid pointer.io_property_data_sizemust be a valid pointer.out_property_datamust be a valid pointer.