AudioFileComponentGetPropertyInfo

Function AudioFileComponentGetPropertyInfo 

pub unsafe extern "C-unwind" fn AudioFileComponentGetPropertyInfo(
    in_component: AudioFileComponent,
    in_property_id: AudioFileComponentPropertyID,
    out_property_size: *mut u32,
    out_writable: *mut u32,
) -> i32
Available on crate feature AudioComponent only.
implements AudioFileGetPropertyInfo.

Parameter inComponent: an AudioFileComponent

Parameter inPropertyID: an AudioFileProperty constant.

Parameter outPropertySize: the size in bytes of the current value of the property. In order to get the property value, you will need a buffer of this size.

Parameter outWritable: will be set to 1 if writable, or 0 if read only.

Returns: returns noErr if successful.

Safety

  • in_component must be a valid pointer.
  • out_property_size must be a valid pointer or null.
  • out_writable must be a valid pointer or null.