pub unsafe extern "C-unwind" fn AudioFileComponentGetUserData(
in_component: AudioFileComponent,
in_user_data_id: u32,
in_index: u32,
io_user_data_size: NonNull<u32>,
out_user_data: NonNull<c_void>,
) -> i32Available on crate feature
AudioComponent only.Expand description
implements AudioFileGetUserData.
Parameter inComponent: an AudioFileComponent
Parameter inUserDataID: the four char code of the chunk.
Parameter inIndex: an index specifying which chunk if there are more than one.
Parameter ioUserDataSize: the size of the buffer on input, size of bytes copied to buffer on output
Parameter outUserData: a pointer to a buffer in which to copy the chunk data.
Returns: returns noErr if successful.
Safety
in_componentmust be a valid pointer.io_user_data_sizemust be a valid pointer.out_user_datamust be a valid pointer.