pub unsafe extern "C-unwind" fn AudioFileComponentGetUserDataSize64(
in_component: AudioFileComponent,
in_user_data_id: u32,
in_index: u32,
out_user_data_size: NonNull<u64>,
) -> i32Available on crate feature
AudioComponent only.Expand description
implements AudioFileGetUserDataSize64
Parameter inComponent: an AudioFileComponent
Parameter inUserDataID: the four char code of the chunk.
Parameter inIndex: an index specifying which chunk if there are more than one.
Parameter outUserDataSize: on output, if successful, the size of the user data chunk.
Returns: returns noErr if successful.
Safety
in_componentmust be a valid pointer.out_user_data_sizemust be a valid pointer.