pub unsafe extern "C-unwind" fn AudioFileComponentInitializeWithCallbacks(
in_component: AudioFileComponent,
in_client_data: NonNull<c_void>,
in_read_func: AudioFile_ReadProc,
in_write_func: AudioFile_WriteProc,
in_get_size_func: AudioFile_GetSizeProc,
in_set_size_func: AudioFile_SetSizeProc,
in_file_type: u32,
in_format: NonNull<AudioStreamBasicDescription>,
in_flags: u32,
) -> i32AudioComponent and AudioFile and objc2-core-audio-types only.Expand description
implements AudioFileInitializeWithCallbacks
Parameter inComponent: an AudioFileComponent
Parameter inClientData: a constant that will be passed to your callbacks.
Parameter inReadFunc: a function that will be called when AudioFile needs to read data.
Parameter inWriteFunc: a function that will be called when AudioFile needs to write data.
Parameter inGetSizeFunc: a function that will be called when AudioFile needs to know the file size.
Parameter inSetSizeFunc: a function that will be called when AudioFile needs to set the file size.
Parameter inFileType: an AudioFileTypeID indicating the type of audio file to which to initialize the file.
Parameter inFormat: an AudioStreamBasicDescription describing the data format that will be
added to the audio file.
Parameter inFlags: relevant flags for creating/opening the file. Currently zero.
Returns: returns noErr if successful.
Safety
in_componentmust be a valid pointer.in_client_datamust be a valid pointer.in_read_funcmust be implemented correctly.in_write_funcmust be implemented correctly.in_get_size_funcmust be implemented correctly.in_set_size_funcmust be implemented correctly.in_formatmust be a valid pointer.