pub unsafe extern "C-unwind" fn AudioFileComponentSetUserData(
in_component: AudioFileComponent,
in_user_data_id: u32,
in_index: u32,
in_user_data_size: u32,
in_user_data: NonNull<c_void>,
) -> i32Available on crate feature
AudioComponent only.Expand description
implements AudioFileSetUserData.
Parameter inComponent: an AudioFileComponent
Parameter inUserDataID: the four char code of the chunk.
Parameter inIndex: an index specifying which chunk if there are more than one.
Parameter inUserDataSize: on input the size of the data to copy, on output, size of bytes copied from the buffer
Parameter inUserData: a pointer to a buffer from which to copy the chunk data
(only the contents of the chunk, not including the chunk header).
Returns: returns noErr if successful.
Safety
in_componentmust be a valid pointer.in_user_datamust be a valid pointer.