pub unsafe extern "C-unwind" fn AudioFileCreateWithURL(
in_file_ref: &CFURL,
in_file_type: AudioFileTypeID,
in_format: NonNull<AudioStreamBasicDescription>,
in_flags: AudioFileFlags,
out_audio_file: NonNull<AudioFileID>,
) -> i32AudioFile and objc2-core-audio-types and objc2-core-foundation only.Expand description
creates a new audio file (or initialises an existing file)
creates a new (or initialises an existing) audio file specified by the URL. Upon success, an AudioFileID is returned which can be used for subsequent calls to the AudioFile APIs.
Parameter inFileRef: an CFURLRef fully specifying the path of the file to create/initialise
Parameter inFileType: an AudioFileTypeID indicating the type of audio file to create.
Parameter inFormat: an AudioStreamBasicDescription describing the data format that will be
added to the audio file.
Parameter inFlags: relevant flags for creating/opening the file.
if kAudioFileFlags_EraseFile is set, it will erase an existing file
if not set, then the Create call will fail if the URL is an existing file
Parameter outAudioFile: if successful, an AudioFileID that can be used for subsequent AudioFile calls.
Returns: returns noErr if successful.
Safety
in_formatmust be a valid pointer.out_audio_filemust be a valid pointer.