pub unsafe extern "C-unwind" fn AudioFileGetGlobalInfoSize(
in_property_id: AudioFilePropertyID,
in_specifier_size: u32,
in_specifier: *mut c_void,
out_data_size: NonNull<u32>,
) -> i32Available on crate feature
AudioFile only.Expand description
Get the size of a global property.
Parameter inPropertyID: an AudioFileGlobalInfo property constant.
Parameter inSpecifierSize: The size of the specifier data.
Parameter inSpecifier: A specifier is a buffer of data used as an input argument to some of the global info properties.
Parameter outDataSize: the size in bytes of the current value of the property. In order to get the property value,
you will need a buffer of this size.
Returns: returns noErr if successful.
Safety
in_specifiermust be a valid pointer or null.out_data_sizemust be a valid pointer.