pub unsafe extern "C-unwind" fn AudioFileGetProperty(
in_audio_file: AudioFileID,
in_property_id: AudioFilePropertyID,
io_data_size: NonNull<u32>,
out_property_data: NonNull<c_void>,
) -> i32Available on crate feature
AudioFile only.Expand description
Copies the value for a property of an AudioFile into a buffer.
Parameter inAudioFile: an AudioFileID.
Parameter inPropertyID: an AudioFileProperty constant.
Parameter ioDataSize: on input the size of the outPropertyData buffer. On output the number of bytes written to the buffer.
Parameter outPropertyData: the buffer in which to write the property data.
Returns: returns noErr if successful.
Safety
in_audio_filemust be a valid pointer.io_data_sizemust be a valid pointer.out_property_datamust be a valid pointer.