pub unsafe extern "C-unwind" fn AudioFileGetUserDataSize(
in_audio_file: AudioFileID,
in_user_data_id: u32,
in_index: u32,
out_user_data_size: NonNull<u32>,
) -> i32Available on crate feature
AudioFile only.Expand description
Get the size of user data in a file
Parameter inAudioFile: an AudioFileID.
Parameter inUserDataID: the four char code of the chunk.
Parameter inIndex: an index specifying which chunk if there are more than one.
Parameter outUserDataSize: on output, if successful, the size of the user data chunk.
Returns: returns noErr if successful.
Safety
in_audio_filemust be a valid pointer.out_user_data_sizemust be a valid pointer.