AudioFileOptimize

Function AudioFileOptimize 

pub unsafe extern "C-unwind" fn AudioFileOptimize(
    in_audio_file: AudioFileID,
) -> i32
Available on crate feature AudioFile only.
Move the audio data to the end of the file and other internal optimizations of the file structure.

Optimize the file so additional audio data can be appended to the existing data. Generally, this will place the audio data at the end of the file so additional writes can be placed to the file end. This can be a potentially expensive and time-consuming operation and should not be used during time critical operations. There is a kAudioFilePropertyIsOptimized property for checking on the optimized state of the file.

Parameter inAudioFile: an AudioFileID.

Returns: returns noErr if successful.

Safety

in_audio_file must be a valid pointer.