AudioFileStreamParseBytes

Function AudioFileStreamParseBytes 

pub unsafe extern "C-unwind" fn AudioFileStreamParseBytes(
    in_audio_file_stream: AudioFileStreamID,
    in_data_byte_size: u32,
    in_data: *const c_void,
    in_flags: AudioFileStreamParseFlags,
) -> i32
Available on crate feature AudioFileStream only.
This call is the means for streams to supply data to the parser. Data is expected to be passed in sequentially from the beginning of the file, without gaps. In the course of parsing, the client’s property and/or packets callbacks may be called. At the end of the stream, this function must be called once with null data pointer and zero data byte size to flush any remaining packets out of the parser.

Parameter inAudioFileStream: The file stream ID

Parameter inDataByteSize: The number of bytes passed in for parsing. Must be zero when flushing the parser.

Parameter inData: The data passed in to be parsed. Must be null when flushing the parser.

Parameter inFlags: If there is a data discontinuity, then kAudioFileStreamParseFlag_Discontinuity should be set true.

Safety

  • in_audio_file_stream must be a valid pointer.
  • in_data must be a valid pointer or null.