AudioFileWritePacketsWithDependencies

Function AudioFileWritePacketsWithDependencies 

pub unsafe extern "C-unwind" fn AudioFileWritePacketsWithDependencies(
    in_audio_file: AudioFileID,
    in_use_cache: bool,
    in_num_bytes: u32,
    in_packet_descriptions: *const AudioStreamPacketDescription,
    in_packet_dependencies: NonNull<AudioStreamPacketDependencyDescription>,
    in_starting_packet: i64,
    io_num_packets: NonNull<u32>,
    in_buffer: NonNull<c_void>,
) -> i32
Available on crate features AudioFile and objc2-core-audio-types only.
Write packets of audio data with corresponding packet dependencies to an audio data file.

For all uncompressed formats, packets == frames.

Parameter inAudioFile: The audio file to write to.

Parameter inUseCache: Set to true if you want to cache the data. Otherwise, set to false.

Parameter inNumBytes: The number of bytes of audio data being written.

Parameter inPacketDescriptions: A pointer to an array of packet descriptions for the audio data. Not all formats require packet descriptions. If no packet descriptions are required, for instance, if you are writing CBR data, pass NULL.

Parameter inPacketDependencies: A pointer to an array of packet dependencies for the audio data. This must not be NULL. To write packets without dependencies, use AudioFileWritePackets instead.

Parameter inStartingPacket: The packet index for the placement of the first provided packet.

Parameter ioNumPackets: On input, a pointer to the number of packets to write. On output, a pointer to the number of packets actually written.

Parameter inBuffer: A pointer to user-allocated memory containing the new audio data to write to the audio data file.

Returns: A result code. See Result Codes.

Safety

  • in_audio_file must be a valid pointer.
  • in_packet_descriptions must be a valid pointer or null.
  • in_packet_dependencies must be a valid pointer.
  • io_num_packets must be a valid pointer.
  • in_buffer must be a valid pointer.