AudioFormatGetProperty

Function AudioFormatGetProperty 

pub unsafe extern "C-unwind" fn AudioFormatGetProperty(
    in_property_id: AudioFormatPropertyID,
    in_specifier_size: u32,
    in_specifier: *const c_void,
    io_property_data_size: *mut u32,
    out_property_data: *mut c_void,
) -> i32
Available on crate feature AudioFormat only.
Retrieve the indicated property data

Parameter inPropertyID: an AudioFormatPropertyID constant.

Parameter inSpecifierSize: The size of the specifier data.

Parameter inSpecifier: A specifier is a buffer of data used as an input argument to some of the properties.

Parameter ioPropertyDataSize: on input the size of the outPropertyData buffer. On output the number of bytes written to the buffer.

Parameter outPropertyData: the buffer in which to write the property data. If outPropertyData is NULL and ioPropertyDataSize is not, the amount that would have been written will be reported.

Returns: returns noErr if successful.

Safety

  • in_specifier must be a valid pointer or null.
  • io_property_data_size must be a valid pointer or null.
  • out_property_data must be a valid pointer or null.