AudioHardwareServiceGetPropertyDataSize

Function AudioHardwareServiceGetPropertyDataSize 

pub unsafe extern "C-unwind" fn AudioHardwareServiceGetPropertyDataSize(
    in_object_id: AudioObjectID,
    in_address: *const AudioObjectPropertyAddress,
    in_qualifier_data_size: u32,
    in_qualifier_data: *const c_void,
    out_data_size: *mut u32,
) -> i32
๐Ÿ‘ŽDeprecated: no longer supported
Available on crate feature objc2-core-audio only.
Queries an AudioObject to find the size of the data for the given property.

Parameter inObjectID: The AudioObject to query.

Parameter inAddress: An AudioObjectPropertyAddress indicating which property is being queried.

Parameter inQualifierDataSize: A UInt32 indicating the size of the buffer pointed to by inQualifierData. Note that not all properties require qualification, in which case this value will be 0.

Parameter inQualifierData: A buffer of data to be used in determining the data of the property being queried. Note that not all properties require qualification, in which case this value will be NULL.

Parameter outDataSize: A UInt32 indicating how many bytes the data for the given property occupies.

Returns: An OSStatus indicating success or failure.

Safety

  • in_address must be a valid pointer.
  • in_qualifier_data must be a valid pointer.
  • out_data_size must be a valid pointer.