AudioHardwareServiceIsPropertySettable

Function AudioHardwareServiceIsPropertySettable 

pub unsafe extern "C-unwind" fn AudioHardwareServiceIsPropertySettable(
    in_object_id: AudioObjectID,
    in_address: *const AudioObjectPropertyAddress,
    out_is_settable: *mut u8,
) -> i32
๐Ÿ‘ŽDeprecated: no longer supported
Available on crate feature objc2-core-audio only.
Queries an AudioObject about whether or not the given property can be set using AudioHardwareServiceSetPropertyData.

Parameter inObjectID: The AudioObject to query.

Parameter inAddress: An AudioObjectPropertyAddress indicating which property is being queried.

Parameter outIsSettable: A Boolean indicating whether or not the property can be set.

Returns: An OSStatus indicating success or failure.

Safety

  • in_address must be a valid pointer.
  • out_is_settable must be a valid pointer.