pub unsafe extern "C-unwind" fn AudioOutputUnitPublish(
in_desc: NonNull<AudioComponentDescription>,
in_name: &CFString,
in_version: u32,
in_output_unit: AudioUnit,
) -> i32๐Deprecated: Inter-App Audio API is deprecated in favor of Audio Units
Available on crate features
AUComponent and AudioComponent and objc2-core-foundation only.Expand description
Register an audio output unit as available to be used as an audio unit by other applications.
Parameter inOutputUnit: The audio output unit to be published.
Parameter inDesc: The AudioComponentDescription under which to register the application.
Parameter inName: The application or component name.
Returns: An OSStatus result code.
This allows a publishing application to register its audio (input/)output unit as being able to be redirected and repurposed as an audio unit effect, generator, music device or music effect by another host application.
Safety
in_descmust be a valid pointer.in_output_unitmust be a valid pointer.