pub unsafe extern "C-unwind" fn AudioQueueCreateTimeline(
in_aq: AudioQueueRef,
out_timeline: NonNull<AudioQueueTimelineRef>,
) -> i32Available on crate feature
AudioQueue only.Expand description
Creates a timeline object.
You need to instantiate a timeline object if you want to know about any timeline discontinuities. See AudioQueueGetCurrentTime for more details.
Parameter inAQ: The audio queue to associate with the new timeline object.
Parameter outTimeline: On return, points to the newly created timeline object.
Returns: An OSStatus result code.
Safety
in_aqmust be a valid pointer.out_timelinemust be a valid pointer.