pub unsafe extern "C-unwind" fn AudioQueueGetParameter(
in_aq: AudioQueueRef,
in_param_id: AudioQueueParameterID,
out_value: NonNull<AudioQueueParameterValue>,
) -> i32Available on crate feature
AudioQueue only.Expand description
Obtains an audio queue parameter value.
You can access the current parameter values for an audio queue at any time with this function.
Parameter inAQ: The audio queue whose parameter value you want to obtain.
Parameter inParamID: The ID of the parameter you want to obtain. In macOS v10.5, audio queues have one
parameter available: kAudioQueueParam_Volume, which controls the queue’s playback
volume.
Parameter outValue: On return, points to the current value of the specified parameter.
Returns: An OSStatus result code.
Safety
in_aqmust be a valid pointer.out_valuemust be a valid pointer.