AudioQueueGetPropertySize

Function AudioQueueGetPropertySize 

pub unsafe extern "C-unwind" fn AudioQueueGetPropertySize(
    in_aq: AudioQueueRef,
    in_id: AudioQueuePropertyID,
    out_data_size: NonNull<u32>,
) -> i32
Available on crate feature AudioQueue only.
Obtains the size of an audio queue property.

Parameter inAQ: The audio queue containing the property value whose size you want to obtain.

Parameter inID: The ID of the property value whose size you want to obtain. See “Audio Queue Property IDs” for possible values.

Parameter outDataSize: On return, points to the size of the specified property value.

Returns: An OSStatus result code.

Safety

  • in_aq must be a valid pointer.
  • out_data_size must be a valid pointer.