AudioQueueOfflineRender

Function AudioQueueOfflineRender 

pub unsafe extern "C-unwind" fn AudioQueueOfflineRender(
    in_aq: AudioQueueRef,
    in_timestamp: NonNull<AudioTimeStamp>,
    io_buffer: AudioQueueBufferRef,
    in_number_frames: u32,
) -> i32
Available on crate features AudioQueue and objc2-core-audio-types only.
Obtain a buffer of audio output from a queue in offline rendering mode.

Parameter inAQ: The output queue from which to obtain output.

Parameter inTimestamp: The point in time corresponding to the beginning of the output buffer. Only mSampleTime is used. mFlags must include kAudioTimeStampSampleTimeValid.

Parameter ioBuffer: The buffer into which the queue will render.

Parameter inNumberFrames: The number of frames of audio to render. Note that fewer frames than requested may be returned. This can happen if insufficient data was enqueued.

Returns: An OSStatus result code.

Safety

  • in_aq must be a valid pointer.
  • in_timestamp must be a valid pointer.
  • io_buffer must be a valid pointer.