AudioQueueProcessingTapGetSourceAudio

Function AudioQueueProcessingTapGetSourceAudio 

pub unsafe extern "C-unwind" fn AudioQueueProcessingTapGetSourceAudio(
    in_aq_tap: AudioQueueProcessingTapRef,
    in_number_frames: u32,
    io_time_stamp: NonNull<AudioTimeStamp>,
    out_flags: NonNull<AudioQueueProcessingTapFlags>,
    out_number_frames: NonNull<u32>,
    io_data: NonNull<AudioBufferList>,
) -> i32
Available on crate features AudioQueue and objc2-core-audio-types only.
Used by a processing tap to retrieve source audio.

This function may only be called from the processing tap’s callback.

Parameter inAQTap: the processing tap

Parameter inNumberFrames: the number of frames the processing tap requires for its processing

Parameter ioTimeStamp: On an input audio queue, the timestamp is returned from this function. On an output audio queue, the caller must provide a continuous timestamp.

Parameter outFlags: flags to describe state about the input requested, e.g. discontinuity/complete

Parameter outNumberFrames: the number of source frames that have been provided by the parent audio queue. This can be less than the number of requested frames specified in inNumberFrames

Parameter ioData: the audio buffer list which will contain the source data. The audio queue owns the buffer pointers if NULL pointers were provided (recommended). In this case the source buffers are only valid for the duration of the processing tap callback. If the buffer pointers are non-NULL, then they must be big enough to hold inNumberFrames, and the audio queue will copy its source data into those buffers.

Returns: An OSStatus result code.

Safety

  • in_aq_tap must be a valid pointer.
  • io_time_stamp must be a valid pointer.
  • out_flags must be a valid pointer.
  • out_number_frames must be a valid pointer.
  • io_data must be a valid pointer.