AudioQueueRemovePropertyListener

Function AudioQueueRemovePropertyListener 

pub unsafe extern "C-unwind" fn AudioQueueRemovePropertyListener(
    in_aq: AudioQueueRef,
    in_id: AudioQueuePropertyID,
    in_proc: AudioQueuePropertyListenerProc,
    in_user_data: *mut c_void,
) -> i32
Available on crate feature AudioQueue only.
Removes a listener callback for a property.

Parameter inAQ: The audio queue that owns the property from which you want to remove a listener.

Parameter inID: The ID of the property from which you want to remove a listener.

Parameter inProc: The listener being removed.

Parameter inUserData: The same inUserData value that was previously passed to AudioQueueAddPropertyListener.

Returns: An OSStatus result code.

Safety

  • in_aq must be a valid pointer.
  • in_proc must be implemented correctly.
  • in_user_data must be a valid pointer or null.