pub unsafe extern "C-unwind" fn AudioQueueReset(
in_aq: AudioQueueRef,
) -> i32AudioQueue only.Expand description
Resets an audio queue.
This function immediately resets an audio queue, flushes any queued buffer, removes all buffers from previously scheduled use, and resets any decoder and digital signal processing (DSP) state information. It also invokes callbacks for any flushed buffers. If you queue any buffers after calling this function, processing does not occur until the decoder and DSP state information is reset. Hence, a discontinuity (that is, a “glitch”) might occur.
Note that when resetting, all pending buffer callbacks are normally invoked during the process of resetting. But if the calling thread is responding to a buffer callback, then it is possible for additional buffer callbacks to occur after AudioQueueReset returns.
Parameter inAQ: The audio queue to reset.
Returns: An OSStatus result code.
Safety
in_aq must be a valid pointer.