pub unsafe extern "C-unwind" fn AudioServicesCreateSystemSoundID(
in_file_url: &CFURL,
out_system_sound_id: NonNull<SystemSoundID>,
) -> i32Available on crate features
AudioServices and objc2-core-foundation only.Expand description
Allows the application to designate an audio file for playback by the System Sound server.
Returned SystemSoundIDs are passed to AudioServicesPlayAlertSoundWithCompletion() and AudioServicesPlaySystemSoundWithCompletion() to be played.
The maximum supported duration for a system sound is 30 secs.
Parameter inFileURL: A CFURLRef for an AudioFile.
Parameter outSystemSoundID: Returns a SystemSoundID.
Safety
out_system_sound_id must be a valid pointer.