AudioServicesGetProperty

Function AudioServicesGetProperty 

pub unsafe extern "C-unwind" fn AudioServicesGetProperty(
    in_property_id: AudioServicesPropertyID,
    in_specifier_size: u32,
    in_specifier: *const c_void,
    io_property_data_size: NonNull<u32>,
    out_property_data: *mut c_void,
) -> i32
Available on crate feature AudioServices only.
Retrieve the indicated property data

Parameter inPropertyID: a AudioServicesPropertyID constant.

Parameter inSpecifierSize: The size of the specifier data.

Parameter inSpecifier: A specifier is a buffer of data used as an input argument to some of the properties.

Parameter ioPropertyDataSize: On input, the size of the outPropertyData buffer. On output the number of bytes written to the buffer.

Parameter outPropertyData: The buffer in which to write the property data. May be NULL if caller only wants ioPropertyDataSize to be filled with the amount that would have been written.

Returns: returns kAudioServicesNoError if successful.

Safety

  • in_specifier must be a valid pointer or null.
  • io_property_data_size must be a valid pointer.
  • out_property_data must be a valid pointer or null.