pub unsafe extern "C-unwind" fn AudioServicesGetPropertyInfo(
in_property_id: AudioServicesPropertyID,
in_specifier_size: u32,
in_specifier: *const c_void,
out_property_data_size: *mut u32,
out_writable: *mut u8,
) -> i32Available on crate feature
AudioServices only.Expand description
Get information about the size of an AudioServices property and whether it can be set.
Parameter inPropertyID: a AudioServicesPropertyID constant.
Parameter inSpecifierSize: The size of the specifier data.
Parameter inSpecifier: A specifier is a buffer of data used as an input argument to some of the
properties.
Parameter outPropertyDataSize: The size in bytes of the current value of the property. In order to get the
property value, you will need a buffer of this size.
Parameter outWritable: Will be set to 1 if writable, or 0 if read only.
Returns: returns kAudioServicesNoError if successful.
Safety
in_specifiermust be a valid pointer or null.out_property_data_sizemust be a valid pointer or null.out_writablemust be a valid pointer or null.