AudioServicesPlayAlertSound

Function AudioServicesPlayAlertSound 

pub unsafe extern "C-unwind" fn AudioServicesPlayAlertSound(
    in_system_sound_id: SystemSoundID,
)
Available on crate feature AudioServices only.
This function will be deprecated in a future release. Use AudioServicesPlayAlertSoundWithCompletion instead.

Play an Alert Sound

Play the provided SystemSoundID with AlertSound behavior.

Parameter inSystemSoundID: A SystemSoundID for the System Sound server to play. On the desktop you can pass the kSystemSoundID_UserPreferredAlert constant to playback the alert sound selected by the user in System Preferences. On iOS there is no preferred user alert sound.