AudioServicesPlaySystemSoundWithCompletion

Function AudioServicesPlaySystemSoundWithCompletion 

pub unsafe extern "C-unwind" fn AudioServicesPlaySystemSoundWithCompletion(
    in_system_sound_id: SystemSoundID,
    in_completion_block: Option<&DynBlock<dyn Fn()>>,
)
Available on crate features AudioServices and block2 only.
Play a system sound

Play the sound designated by the provided SystemSoundID.

Parameter inSystemSoundID: The SystemSoundID to be played.

Parameter inCompletionBlock: The completion block gets executed for every attempt to play a system sound irrespective of success or failure. The callbacks are issued on a serial queue and the client is responsible for handling thread safety.