AudioServicesSetProperty

Function AudioServicesSetProperty 

pub unsafe extern "C-unwind" fn AudioServicesSetProperty(
    in_property_id: AudioServicesPropertyID,
    in_specifier_size: u32,
    in_specifier: *const c_void,
    in_property_data_size: u32,
    in_property_data: NonNull<c_void>,
) -> i32
Available on crate feature AudioServices only.
Set the indicated property data

Parameter inPropertyID: a AudioServicesPropertyID constant.

Parameter inSpecifierSize: The size of the specifier data.

Parameter inSpecifier: A specifier is a buffer of data used as an input argument to some of the properties.

Parameter inPropertyDataSize: The size of the inPropertyData buffer.

Parameter inPropertyData: The buffer containing the property data.

Returns: returns kAudioServicesNoError if successful.

Safety

  • in_specifier must be a valid pointer or null.
  • in_property_data must be a valid pointer.