pub unsafe extern "C-unwind" fn AudioSessionGetProperty(
in_id: AudioSessionPropertyID,
io_data_size: *mut u32,
out_data: *mut c_void,
) -> i32AudioSession only.Expand description
Get the value of a property.
This function can be called to get the value for a property of the AudioSession. Valid properties are listed in an enum above.
Parameter inID: The AudioSessionPropertyID for which we want to get the value.
Parameter ioDataSize: The size of the data payload.
On entry it should contain the size of the memory pointed to by outData.
On exit it will contain the actual size of the data.
Parameter outData: The data for the property will be copied here.
Returns: kAudioSessionNoError if the operation was successful. If the property is a write-only property or only available by way of property listeners, kAudioSessionUnsupportedPropertyError will be returned. Other error codes listed under AudioSession Error Constants also apply to this function.
Safety
io_data_sizemust be a valid pointer.out_datamust be a valid pointer.