pub unsafe extern "C-unwind" fn AudioSessionRemovePropertyListenerWithUserData(
in_id: AudioSessionPropertyID,
in_proc: AudioSessionPropertyListener,
in_client_data: *mut c_void,
) -> i32AudioSession only.Expand description
Remove a property listener.
This function can be called to remove the listener for a property. The caller provides the same proc and user data that was used to add the listener. This ensures that there can be more than one listener established for a given property ID, and each listener can be removed as requested. Valid properties are listed above.
Parameter inID: The AudioSessionPropertyID for which we want to remove the listener.
Parameter inProc: The proc that was used to add the listener that needs to be removed.
Parameter inClientData: The client data that was used to add the listener that needs to be removed.
Returns: kAudioSessionNoError if the operation was successful. If the property does not support listeners, kAudioSessionUnsupportedPropertyError will be returned. Other error codes listed under AudioSession Error Constants also apply to this function.
Safety
in_procmust be implemented correctly.in_client_datamust be a valid pointer.