pub unsafe extern "C-unwind" fn AudioSessionSetActive(
active: bool,
) -> i32👎Deprecated: no longer supported
Available on crate feature
AudioSession only.Expand description
Activate or deactivate the AudioSession.
Call this function with active set to true to activate this AudioSession (interrupt the currently active AudioSession). Call this function with active set to false to deactivate this AudioSession (allow another interrupted AudioSession to resume). When active is true this call may fail if the currently active AudioSession has a higher priority.
Parameter active: A Boolean indicating if you want to make this AudioSession active or inactive.