pub unsafe extern "C-unwind" fn AudioSessionSetActiveWithFlags(
active: bool,
in_flags: u32,
) -> i32👎Deprecated: no longer supported
Available on crate feature
AudioSession only.Expand description
Same functionality as AudioSessionSetActive, with an additional flags parameter for refining behavior.
Call this function with active set to true to activate this AudioSession (interrupt the currently active AudioSession). Call this function with active set to false to deactivate this AudioSession (allow another interrupted AudioSession to resume). Pass in one or more flags to refine the behavior during activation or deactivation. When active is true this call may fail if the currently active AudioSession has a higher priority.
Parameter active: A Boolean indicating if you want to make this AudioSession active or inactive.
Parameter inFlags: A bitmap containing one or more flags from the AudioSessionActivationFlags enum.