AudioSessionSetProperty

Function AudioSessionSetProperty 

pub unsafe extern "C-unwind" fn AudioSessionSetProperty(
    in_id: AudioSessionPropertyID,
    in_data_size: u32,
    in_data: *const c_void,
) -> i32
๐Ÿ‘ŽDeprecated: no longer supported
Available on crate feature AudioSession only.
Set the value of a property.

This function can be called to set the value for a property of the AudioSession. Valid properties are listed in an enum above.

Parameter inID: The AudioSessionPropertyID for which we want to set the value.

Parameter inDataSize: The size of the data payload.

Parameter inData: The data for the property we want to set.

Returns: kAudioSessionNoError if the operation was successful. If the property is a read-only property or an invalid property value is passed in, kAudioSessionUnsupportedPropertyError will be returned. Other error codes listed under AudioSession Error Constants also apply to this function.

Safety

in_data must be a valid pointer.