AudioUnitAddRenderNotify

Function AudioUnitAddRenderNotify 

pub unsafe extern "C-unwind" fn AudioUnitAddRenderNotify(
    in_unit: AudioUnit,
    in_proc: AURenderCallback,
    in_proc_user_data: *mut c_void,
) -> i32
Available on crate features AUComponent and AudioComponent and objc2-core-audio-types only.
a notification callback to call when an audio unit is asked to render

allows an application to register a callback with an audio unit for whenever the audio unit is asked to render. The callback is called both before the audio unit performs its render operations (the render flag’s pre-render bit is set) and after the audio unit has completed its render operations (the render flag’s post-render bit is set). On post-render, the audio buffer list (ioData) will contain valid audio data that was rendered by the audio unit.

The inProc and inProcUserData are treated as a tuple entity, so when wanting to remove one, both the inProc and its inProcUserData must be specified

Parameter inUnit: the audio unit

Parameter inProc: an AURenderCallback proc

Parameter inProcUserData: the user data that will be provided with the proc when it is called

Returns: noErr, or an audio unit error code

Safety

  • in_unit must be a valid pointer.
  • in_proc must be implemented correctly.
  • in_proc_user_data must be a valid pointer or null.