AudioUnitExtensionSetComponentList

Function AudioUnitExtensionSetComponentList 

pub unsafe extern "C-unwind" fn AudioUnitExtensionSetComponentList(
    extension_identifier: &CFString,
    audio_component_info: Option<&CFArray>,
) -> i32
Available on crate features AUComponent and objc2-core-foundation only.
Allows the implementor of an audio unit extension to dynamically modify the list of component registrations for the extension.

Parameter extensionIdentifier: The bundle ID of the audio unit extension.

Parameter audioComponentInfo: An array of dictionaries, one for each component, in the same format as described in AudioComponent.h for the Info.plist key “AudioComponents”.

Returns: An OSStatus result code.

Note that the bundle ID of the process calling this API must prefix (or match) the provided extension identifier.

Safety

audio_component_info generic must be of the correct type.