AudioUnitGetParameter

Function AudioUnitGetParameter 

pub unsafe extern "C-unwind" fn AudioUnitGetParameter(
    in_unit: AudioUnit,
    in_id: AudioUnitParameterID,
    in_scope: AudioUnitScope,
    in_element: AudioUnitElement,
    out_value: NonNull<AudioUnitParameterValue>,
) -> i32
Available on crate features AUComponent and AudioComponent only.
Get the value of a parameter

Get the value of a parameter as specified by its ID, scope and element.

Parameter inUnit: the audio unit

Parameter inID: the parameter ID

Parameter inScope: the scope for the parameter

Parameter inElement: the element on the scope for the parameter

Parameter outValue: Must be non-null, and upon success will contain the current value for the specified parameter

Returns: noErr, or an audio unit error code (such as InvalidParameter)

Safety

  • in_unit must be a valid pointer.
  • out_value must be a valid pointer.