AudioUnitGetPropertyInfo

Function AudioUnitGetPropertyInfo 

pub unsafe extern "C-unwind" fn AudioUnitGetPropertyInfo(
    in_unit: AudioUnit,
    in_id: AudioUnitPropertyID,
    in_scope: AudioUnitScope,
    in_element: AudioUnitElement,
    out_data_size: *mut u32,
    out_writable: *mut u8,
) -> i32
Available on crate features AUComponent and AudioComponent only.
retrieves information about a specified property

The API can be used to retrieve both the size of the property, and whether it is writable or not. In order to get a general answer on the capability of an audio unit, this function should be called before the audio unit is initialized (as some properties are writable when the audio unit is initialized, and others not)

Parameter inUnit: the audio unit

Parameter inID: the property identifier

Parameter inScope: the scope of the property

Parameter inElement: the element of the scope

Parameter outDataSize: if not null, then will retrieve the maximum size for the property. if null, then it is ignored

Parameter outWritable: if not null, then will retrieve whether the property can be written or not. if null, then it is ignored

Returns: noErr, or various audio unit errors related to properties

Safety

  • in_unit must be a valid pointer.
  • out_data_size must be a valid pointer or null.
  • out_writable must be a valid pointer or null.