AudioUnitRemovePropertyListenerWithUserData

Function AudioUnitRemovePropertyListenerWithUserData 

pub unsafe extern "C-unwind" fn AudioUnitRemovePropertyListenerWithUserData(
    in_unit: AudioUnit,
    in_id: AudioUnitPropertyID,
    in_proc: AudioUnitPropertyListenerProc,
    in_proc_user_data: *mut c_void,
) -> i32
Available on crate features AUComponent and AudioComponent only.
remove a previously registered property listener

Removes a previously registered property listener as specified by the inProc and inProcUser data as paired to the property identifier

Parameter inUnit: the audio unit

Parameter inID: the property identifier

Parameter inProc: the procedure previously registered

Parameter inProcUserData: the user data paired with the provided inProc

Returns: noErr, or various audio unit errors related to properties

Safety

  • in_unit must be a valid pointer.
  • in_proc must be implemented correctly.
  • in_proc_user_data must be a valid pointer or null.