CAClockGetProperty

Function CAClockGetProperty 

pub unsafe extern "C-unwind" fn CAClockGetProperty(
    in_ca_clock: CAClockRef,
    in_property_id: CAClockPropertyID,
    io_property_data_size: NonNull<u32>,
    out_property_data: NonNull<c_void>,
) -> i32
Gets the current value of a clock’s property.

Parameter inCAClock: The clock object.

Parameter inPropertyID: The property being fetched.

Parameter ioPropertyDataSize: On entry, the size (in bytes) of the memory pointed to by outPropertyData. On exit, the actual size of the property data returned.

Parameter outPropertyData: The value of the property is copied to the memory this points to.

Returns: An OSStatus error code.

Safety

  • in_ca_clock must be a valid pointer.
  • io_property_data_size must be a valid pointer.
  • out_property_data must be a valid pointer.