CAClockGetPropertyInfo

Function CAClockGetPropertyInfo 

pub unsafe extern "C-unwind" fn CAClockGetPropertyInfo(
    in_ca_clock: CAClockRef,
    in_property_id: CAClockPropertyID,
    out_size: *mut u32,
    out_writable: *mut u8,
) -> i32
Gets information about a clock’s property.

Parameter inCAClock: The clock object.

Parameter inPropertyID: The property being queried.

Parameter outSize: If non-null, on exit, this is set to the size of the property’s value.

Parameter outWritable: If non-null, on exit, this indicates whether the property value is settable.

Returns: An OSStatus error code.

Safety

  • in_ca_clock must be a valid pointer.
  • out_size must be a valid pointer or null.
  • out_writable must be a valid pointer or null.