CAClockSetPlayRate

Function CAClockSetPlayRate 

pub unsafe extern "C-unwind" fn CAClockSetPlayRate(
    in_ca_clock: CAClockRef,
    in_play_rate: f64,
) -> i32
Alter the clock’s playback rate.

Adjusts the ratio between the timebase and media time; e.g. at 0.5, the media time will move half as quickly as timebase time.

Parameter inCAClock: The clock object.

Parameter inPlayRate: The clock’s desired play rate.

Returns: An OSStatus error code.

Safety

in_ca_clock must be a valid pointer.