pub unsafe extern "C-unwind" fn ExtAudioFileGetProperty(
in_ext_audio_file: ExtAudioFileRef,
in_property_id: ExtAudioFilePropertyID,
io_property_data_size: NonNull<u32>,
out_property_data: NonNull<c_void>,
) -> i32Available on crate feature
ExtendedAudioFile only.Expand description
Get a property value.
Parameter inExtAudioFile: The extended audio file object.
Parameter inPropertyID: The property being fetched.
Parameter ioPropertyDataSize: On entry, the size (in bytes) of the memory pointed to by outPropertyData.
On exit, the actual size of the property data returned.
Parameter outPropertyData: The value of the property is copied to the memory this points to.
Returns: An OSStatus error code.
Safety
in_ext_audio_filemust be a valid pointer.io_property_data_sizemust be a valid pointer.out_property_datamust be a valid pointer.