ExtAudioFileGetPropertyInfo

Function ExtAudioFileGetPropertyInfo 

pub unsafe extern "C-unwind" fn ExtAudioFileGetPropertyInfo(
    in_ext_audio_file: ExtAudioFileRef,
    in_property_id: ExtAudioFilePropertyID,
    out_size: *mut u32,
    out_writable: *mut u8,
) -> i32
Available on crate feature ExtendedAudioFile only.
Get information about a property

Parameter inExtAudioFile: The extended audio file object.

Parameter inPropertyID: The property being queried.

Parameter outSize: If non-null, on exit, this is set to the size of the property’s value.

Parameter outWritable: If non-null, on exit, this indicates whether the property value is settable.

Returns: An OSStatus error code.

Safety

  • in_ext_audio_file must be a valid pointer.
  • out_size must be a valid pointer or null.
  • out_writable must be a valid pointer or null.