ExtAudioFileSeek

Function ExtAudioFileSeek 

pub unsafe extern "C-unwind" fn ExtAudioFileSeek(
    in_ext_audio_file: ExtAudioFileRef,
    in_frame_offset: i64,
) -> i32
Available on crate feature ExtendedAudioFile only.
Seek to a specific frame position.

Parameter inExtAudioFile: The extended audio file object.

Parameter inFrameOffset: The desired seek position, in sample frames, relative to the beginning of the file. This is specified in the sample rate and frame count of the file’s format (not the client format)

Returns: An OSStatus error code.

Sets the file’s read position to the specified sample frame number. The next call to ExtAudioFileRead will return samples from precisely this location, even if it is located in the middle of a packet.

This function’s behavior with files open for writing is currently undefined.

Safety

in_ext_audio_file must be a valid pointer.