MusicDeviceStopNote

Function MusicDeviceStopNote 

pub unsafe extern "C-unwind" fn MusicDeviceStopNote(
    in_unit: MusicDeviceComponent,
    in_group_id: MusicDeviceGroupID,
    in_note_instance_id: NoteInstanceID,
    in_offset_sample_frame: u32,
) -> i32
Available on crate features AudioComponent and MusicDevice only.
used to stop notes started with the MusicDeviceStartNote call

This call is used to stop notes that have been started with the MusicDeviceStartNote call; both the group ID that the note was started on and the noteInstanceID should be specified.

Parameter inUnit: The audio unit

Parameter inGroupID: the group ID

Parameter inNoteInstanceID: the note instance ID

Parameter inOffsetSampleFrame: the sample offset within the next buffer rendered that the note should be turned off at

Returns: noErr, or an audio unit error code

Safety

in_unit must be a valid pointer.