MusicEventIteratorGetEventInfo

Function MusicEventIteratorGetEventInfo 

pub unsafe extern "C-unwind" fn MusicEventIteratorGetEventInfo(
    in_iterator: MusicEventIterator,
    out_time_stamp: NonNull<MusicTimeStamp>,
    out_event_type: NonNull<MusicEventType>,
    out_event_data: NonNull<*const c_void>,
    out_event_data_size: NonNull<u32>,
) -> i32
Available on crate feature MusicPlayer only.
Retrieves the event data at the iterator.

Retrieves the event and other information from the iterator’s current position.

If you do not want specific information (eg, the time stamp) pass in NULL for that parameter.

Parameter inIterator: the iterator

Parameter outTimeStamp: the time stamp of the event

Parameter outEventType: one of kMusicEventType_XXX that indicates what kind of event type the iterator is currently pointing too

Parameter outEventData: a reference to the event data. The type of data is described by the eventType. This data is read only and should not be edited in place.

Parameter outEventDataSize: the size of the data referenced by outEventData

Safety

  • in_iterator must be a valid pointer.
  • out_time_stamp must be a valid pointer.
  • out_event_type must be a valid pointer.
  • out_event_data must be a valid pointer.
  • out_event_data_size must be a valid pointer.