MusicEventIteratorNextEvent

Function MusicEventIteratorNextEvent 

pub unsafe extern "C-unwind" fn MusicEventIteratorNextEvent(
    in_iterator: MusicEventIterator,
) -> i32
Available on crate feature MusicPlayer only.
Move the iterator to the next event

If the iterator was at the last event, then it will move past the last event and will no longer point to an event. You can use check MusicEventIteratorHasCurrentEvent to see if there is an event at the iterator’s current position. See also MusicEventIteratorHasNextEvent.

Typically this call is used to move the iterator forwards through the track’s events.

Parameter inIterator: the iterator

Safety

in_iterator must be a valid pointer.