MusicEventIteratorPreviousEvent

Function MusicEventIteratorPreviousEvent 

pub unsafe extern "C-unwind" fn MusicEventIteratorPreviousEvent(
    in_iterator: MusicEventIterator,
) -> i32
Available on crate feature MusicPlayer only.
Move the iterator to the previous event

If the iterator was at the first event, then it will leave the iterator unchanged and return an error. See also MusicEventIteratorHasPreviousEvent

Typically this call is used to move the iterator backwards through the track’s events.

Parameter inIterator: the iterator

Safety

in_iterator must be a valid pointer.