MusicEventIteratorSetEventInfo

Function MusicEventIteratorSetEventInfo 

pub unsafe extern "C-unwind" fn MusicEventIteratorSetEventInfo(
    in_iterator: MusicEventIterator,
    in_event_type: MusicEventType,
    in_event_data: NonNull<c_void>,
) -> i32
Available on crate feature MusicPlayer only.
Changes the type or value of an event

Allows you to change either the event type, or the values of the event data, that the iterator is currently pointing too. You cannot change the event’s time (to do that you should use MusicEventIteratorSetEventTime).

Parameter inIterator: the iterator

Parameter inEventType: the new (or existing) type of the event you are changing

Parameter inEventData: the new event data. The size and type of this event data must match the inEventType

Safety

  • in_iterator must be a valid pointer.
  • in_event_data must be a valid pointer.