pub unsafe extern "C-unwind" fn MusicPlayerIsPlaying(
in_player: MusicPlayer,
out_is_playing: NonNull<u8>,
) -> i32Available on crate feature
MusicPlayer only.Expand description
Returns the playing state of the player. “Is it playing?”
This call returns a non-zero value in outIsPlaying if the player has been started and not stopped. It may have “played” past the events of the attached MusicSequence, but it is still considered to be playing (and its time value increasing) until it is explicitly stopped
Parameter inPlayer: the player
Parameter outIsPlaying: false if not, true (non-zero) if is playing
Safety
in_playermust be a valid pointer.out_is_playingmust be a valid pointer.