MusicPlayerPreroll

Function MusicPlayerPreroll 

pub unsafe extern "C-unwind" fn MusicPlayerPreroll(
    in_player: MusicPlayer,
) -> i32
Available on crate feature MusicPlayer only.
Prepare the player for playing

Allows the player to prepare its state so that starting is has a lower latency. If a player is started without being prerolled, the player will pre-roll itself and then start.

Parameter inPlayer: the player

Safety

in_player must be a valid pointer.