MusicPlayerSetTime

Function MusicPlayerSetTime 

pub unsafe extern "C-unwind" fn MusicPlayerSetTime(
    in_player: MusicPlayer,
    in_time: MusicTimeStamp,
) -> i32
Available on crate feature MusicPlayer only.
Set the current time on the player

The Get and Set Time calls take a specification of time as beats. This positions the player to the specified time based on the currently set sequence. No range checking on the time value is done. This can be set on a playing player (in which case playing will be resumed from the new time).

Parameter inPlayer: the player

Parameter inTime: the new time value

Safety

in_player must be a valid pointer.