pub unsafe extern "C-unwind" fn MusicSequenceFileCreateData(
in_sequence: MusicSequence,
in_file_type: MusicSequenceFileTypeID,
in_flags: MusicSequenceFileFlags,
in_resolution: i16,
out_data: NonNull<*const CFData>,
) -> i32Available on crate features
MusicPlayer and objc2-core-foundation only.Expand description
Create a data object from a sequence
The same basic parameters apply to this as with the MusicSequenceFileCreate function. The difference being that that function will create a file on disk, whereas this one will create a CFData object that is a file in memory. The CFData object should be released by the caller.
Parameter inSequence: the sequence
Parameter inFileType: the type of file to create
Parameter inFlags: flags to control the file creation
Parameter inResolution: the resolution (depending on file type and sequence type)
Parameter outData: the resulting data object
Safety
in_sequencemust be a valid pointer.out_datamust be a valid pointer.