MusicTrackGetProperty

Function MusicTrackGetProperty 

pub unsafe extern "C-unwind" fn MusicTrackGetProperty(
    in_track: MusicTrack,
    in_property_id: u32,
    out_data: NonNull<c_void>,
    io_length: NonNull<u32>,
) -> i32
Available on crate feature MusicPlayer only.
Gets the specified property value

If outData is NULL, then the size of the data will be passed back in ioLength This allows the client to allocate a buffer of the correct size (useful for variable length properties – currently all properties have fixed size) Property values are always get and set by reference

Parameter inTrack: the track

Parameter inPropertyID: the property ID

Parameter outData: if not NULL, points to data of size ioLength

Parameter ioLength: on input the available size of outData, on output the size of the valid data that outData will then point too.

Safety

  • in_track must be a valid pointer.
  • out_data must be a valid pointer.
  • io_length must be a valid pointer.