pub unsafe extern "C-unwind" fn MusicTrackMerge(
in_source_track: MusicTrack,
in_source_start_time: MusicTimeStamp,
in_source_end_time: MusicTimeStamp,
in_dest_track: MusicTrack,
in_dest_insert_time: MusicTimeStamp,
) -> i32Available on crate feature
MusicPlayer only.Expand description
Copies events from one track and merges them into another
Copies all of the events with the specified time range of the source track. It then merges those events into the destination track starting at inDestInsertTime.
All time ranges are [starttime < endtime]
Parameter inSourceTrack: the source track
Parameter inSourceStartTime: the start time for the range of events
Parameter inSourceEndTime: the end time up to which will form the range of the events to copy from the source track
Parameter inDestTrack: the destination track to copy too
Parameter inDestInsertTime: the time at which the copied events will be merged.
Safety
in_source_trackmust be a valid pointer.in_dest_trackmust be a valid pointer.