MusicTrackNewExtendedNoteEvent

Function MusicTrackNewExtendedNoteEvent 

pub unsafe extern "C-unwind" fn MusicTrackNewExtendedNoteEvent(
    in_track: MusicTrack,
    in_time_stamp: MusicTimeStamp,
    in_info: NonNull<ExtendedNoteOnEvent>,
) -> i32
Available on crate features AUComponent and MusicDevice and MusicPlayer only.
Adds a ExtendedNoteOnEvent to a track

The event is added at the specified time stamp. The time stamp should not be less than zero.

Parameter inTrack: the track

Parameter inTimeStamp: the time stamp

Parameter inInfo: the event

Safety

  • in_track must be a valid pointer.
  • in_info must be a valid pointer.