pub unsafe extern "C-unwind" fn MusicTrackNewUserEvent(
in_track: MusicTrack,
in_time_stamp: MusicTimeStamp,
in_user_data: NonNull<MusicEventUserData>,
) -> i32Available on crate feature
MusicPlayer only.Expand description
Adds a MusicEventUserData event to a track
The event is added at the specified time stamp. The time stamp should not be less than zero.
Parameter inTrack: the track
Parameter inTimeStamp: the time stamp
Parameter inUserData: the event
Safety
in_trackmust be a valid pointer.in_user_datamust be a valid pointer.