pub unsafe extern "C-unwind" fn NewMusicEventIterator(
in_track: MusicTrack,
out_iterator: NonNull<MusicEventIterator>,
) -> i32Available on crate feature
MusicPlayer only.Expand description
Creates an iterator to iterator over a track’s events
The iterator should be considered invalid if a track is edited. In that case you should create a new iterator and seek it to the desired position.
Parameter inTrack: the track upon which to iterate
Parameter outIterator: the new iterator
Safety
in_trackmust be a valid pointer.out_iteratormust be a valid pointer.