AUAudioUnitBusArray

Struct AUAudioUnitBusArray 

pub struct AUAudioUnitBusArray { /* private fields */ }
Available on crate feature AUAudioUnit only.
Container for an audio unit’s input or output busses.

Hosts can observe a bus property across all busses by using KVO on this object, without having to observe it on each individual bus. (One could add listeners to individual busses, but that means one has to observe bus count changes and add/remove listeners in response. Also, NSArray’s addObserver:toObjectsAtIndexes:forKeyPath:options:context: is problematic; it does not let the individual objects override the observation request, and so a bus which is proxying a bus in an extension process does not get the message.)

Some audio units (e.g. mixers) support variable numbers of busses, via subclassing. When the bus count changes, a KVO notification is sent on “inputBusses” or “outputBusses,” as appropriate.

Subclassers should see also the AUAudioUnitBusImplementation category.

The bus array is bridged to the v2 property kAudioUnitProperty_ElementCount.

See also Apple’s documentation

Implementations

Source

impl AUAudioUnitBusArray

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

pub unsafe fn initWithAudioUnit_busType_busses( this: Allocated<Self>, owner: &AUAudioUnit, bus_type: AUAudioUnitBusType, bus_array: &NSArray<AUAudioUnitBus>, ) -> Retained<Self>

Initializes by making a copy of the supplied bus array.

pub unsafe fn initWithAudioUnit_busType( this: Allocated<Self>, owner: &AUAudioUnit, bus_type: AUAudioUnitBusType, ) -> Retained<Self>

Initializes an empty bus array.

pub unsafe fn count(&self) -> NSUInteger

pub unsafe fn objectAtIndexedSubscript( &self, index: NSUInteger, ) -> Retained<AUAudioUnitBus>

pub unsafe fn isCountChangeable(&self) -> bool

Whether the array can have a variable number of busses.

The base implementation returns false.

pub unsafe fn setBusCount_error( &self, count: NSUInteger, ) -> Result<(), Retained<NSError>>

Change the number of busses in the array.

pub unsafe fn addObserverToAllBusses_forKeyPath_options_context( &self, observer: &NSObject, key_path: &NSString, options: NSKeyValueObservingOptions, context: *mut c_void, )

Add a KVO observer for a property on all busses in the array.

Safety
  • observer should be of the correct type.
  • context must be a valid pointer or null.
pub unsafe fn removeObserverFromAllBusses_forKeyPath_context( &self, observer: &NSObject, key_path: &NSString, context: *mut c_void, )

Remove a KVO observer for a property on all busses in the array.

Safety
  • observer should be of the correct type.
  • context must be a valid pointer or null.
pub unsafe fn ownerAudioUnit(&self) -> Retained<AUAudioUnit>

The audio unit that owns the bus.

Safety

This is not retained internally, you must ensure the object is still alive.

pub unsafe fn busType(&self) -> AUAudioUnitBusType

Which bus array this is (input or output).

Source

impl AUAudioUnitBusArray

Methods declared on superclass NSObject.

pub unsafe fn new() -> Retained<Self>

Source

impl AUAudioUnitBusArray

AUAudioUnitBusImplementation.

Aspects of AUAudioUnitBusArray of interest only to subclassers.

pub unsafe fn replaceBusses(&self, bus_array: &NSArray<AUAudioUnitBus>)

Available on crate feature AUAudioUnitImplementation only.

Sets the bus array to be a copy of the supplied array. The base class issues KVO notifications.

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated: this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}