#[repr(transparent)]pub struct AUHostTransportStateFlags(pub NSUInteger);AUAudioUnit only.Expand description
Flags describing the host’s transport state.
True if, since the callback was last called, there was a change to the state of, or discontinuities in, the host’s transport. Can indicate such state changes as start/stop, or seeking to another position in the timeline.
True if the transport is moving.
True if the host is recording, or prepared to record. Can be true with or without the transport moving.
True if the host is cycling or looping.
See also Apple’s documentation
Tuple Fields
0: NSUIntegerImplementations
Sourceimpl AUHostTransportStateFlags
impl AUHostTransportStateFlags
Sourcepub const fn bits(&self) -> NSUInteger
pub const fn bits(&self) -> NSUInteger
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: NSUInteger) -> Option<Self>
pub const fn from_bits(bits: NSUInteger) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: NSUInteger) -> Self
pub const fn from_bits_truncate(bits: NSUInteger) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: NSUInteger) -> Self
pub const fn from_bits_retain(bits: NSUInteger) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl AUHostTransportStateFlags
impl AUHostTransportStateFlags
Sourcepub const fn iter(&self) -> Iter<AUHostTransportStateFlags>
pub const fn iter(&self) -> Iter<AUHostTransportStateFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AUHostTransportStateFlags>
pub const fn iter_names(&self) -> IterNames<AUHostTransportStateFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.