#[repr(C)]pub struct AUParameterMIDIMapping {
pub mScope: AudioUnitScope,
pub mElement: AudioUnitElement,
pub mParameterID: AudioUnitParameterID,
pub mFlags: AUParameterMIDIMappingFlags,
pub mSubRangeMin: AudioUnitParameterValue,
pub mSubRangeMax: AudioUnitParameterValue,
pub mStatus: u8,
pub mData1: u8,
pub reserved1: u8,
pub reserved2: u8,
pub reserved3: u32,
}Available on crate features
AUComponent and AudioUnitProperties only.Expand description
Represents a mapping between a MIDI message and an audio unit’s parameter.
The reserved fields in this structure are for future use. In the current implementation, they help align the structure to 64 bit size. Do not use the names of these fields in a host application. They are subject to change.
See also Apple’s documentation
Fields
mScope: AudioUnitScopemElement: AudioUnitElementmParameterID: AudioUnitParameterIDmFlags: AUParameterMIDIMappingFlagsmSubRangeMin: AudioUnitParameterValuemSubRangeMax: AudioUnitParameterValuemStatus: u8mData1: u8reserved1: u8reserved2: u8reserved3: u32Trait Implementations
Sourceimpl Clone for AUParameterMIDIMapping
impl Clone for AUParameterMIDIMapping
Sourcefn clone(&self) -> AUParameterMIDIMapping
fn clone(&self) -> AUParameterMIDIMapping
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AUParameterMIDIMapping
impl Debug for AUParameterMIDIMapping
Sourceimpl Encode for AUParameterMIDIMapping
impl Encode for AUParameterMIDIMapping
Sourceimpl PartialEq for AUParameterMIDIMapping
impl PartialEq for AUParameterMIDIMapping
Sourceimpl RefEncode for AUParameterMIDIMapping
impl RefEncode for AUParameterMIDIMapping
Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl Copy for AUParameterMIDIMapping
impl StructuralPartialEq for AUParameterMIDIMapping