AUParameterMIDIMappingFlags

Struct AUParameterMIDIMappingFlags 

#[repr(transparent)]
pub struct AUParameterMIDIMappingFlags(pub u32);
Available on crate feature AudioUnitProperties only.
General defined values to customize the behavior of parameter-to-MIDI mappings

If this flag is set and the value of the mStatus field is a MIDI channel message, then the MIDI channel number in the status byte is ignored; the mapping is from the specified MIDI message on any channel.

If this flag is set and the value of the mStatus field is a Note On, Note Off, or Polyphonic Pressure message, the message’s note number is ignored. The mapping is from any note number.

Set this flag if the MIDI control should map only to a sub-range of the parameter’s value. Then specify that range in the mSubRangeMin and mSubRangeMax member fields.

Intended for Boolean typed parameters. When this property is set, it means that the parameter’s value should be toggled when the mapped MIDI message is received. For example, if the parameter’s value is currently TRUE, when the mapped MIDI message is received the value changes to FALSE.

This property is useful when mapping a parameter to a MIDI Controller. When set, it indicates that the parameter can assume only two values: on or off. For this reason, a parameter associated with this property is typically Boolean. For example, if this property is set for a parameter mapped to a sustain pedal MIDI controller, controller values from 0 to 64 result in the parameter switched to its “off” state; controller values from 65 to 127 result in the parameter switched to its “on” state.

This property works in connection with the kAUParameterMIDIMapping_Bipolar_On property. The value of the kAUParameterMIDIMapping_Bipolar_On property

Determines whether the “on” state of a parameter is mapped to the “on” or “off” state of the associated MIDI controller. Only valid if the kAUParameterMIDIMapping_Bipolar property is set.

See also Apple’s documentation

Tuple Fields

0: u32

Implementations

Source

impl AUParameterMIDIMappingFlags

pub const AnyChannelFlag: Self

pub const AnyNoteFlag: Self

pub const SubRange: Self

pub const Toggle: Self

pub const Bipolar: Self

pub const Bipolar_On: Self

Source

impl AUParameterMIDIMappingFlags

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl AUParameterMIDIMappingFlags

pub const fn iter(&self) -> Iter<AUParameterMIDIMappingFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<AUParameterMIDIMappingFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.