#[repr(transparent)]pub struct AUSpatialMixerOutputType(pub u32);Available on crate feature
AudioUnitProperties only.Expand description
Render for headphones.
Render for built-in speakers. The spatialization is optimized for current hardware and will not be suitable for playback on other hardware. On iOS devices, the rendering may be specific to device orientation. Non-realtime rendering may not provide intended results if the orientation changes between rendering the audio and playing it back.
Render for external speakers based on the mixer’s output channel layout.
See also Apple’s documentation
Tuple Fields
0: u32Implementations
Sourceimpl AUSpatialMixerOutputType
impl AUSpatialMixerOutputType
pub const SpatialMixerOutputType_Headphones: Self
pub const SpatialMixerOutputType_BuiltInSpeakers: Self
pub const SpatialMixerOutputType_ExternalSpeakers: Self