#[repr(transparent)]pub struct AUSpatialMixerPointSourceInHeadMode(pub u32);Available on crate feature
AudioUnitProperties only.Expand description
This setting only affects spatialization when using kSpatializationAlgorithm_UseOutputType with kSpatialMixerSourceMode_PointSource.
A point source remains a single mono source inside the listener’s head regardless of the channels it consists of.
A point source splits into bypass inside the listener’s head. This enables transitions between traditional, non-spatialized rendering and spatialized sources outside the listener’s head.
See also Apple’s documentation
Tuple Fields
0: u32Implementations
Sourceimpl AUSpatialMixerPointSourceInHeadMode
impl AUSpatialMixerPointSourceInHeadMode
pub const SpatialMixerPointSourceInHeadMode_Mono: Self
pub const SpatialMixerPointSourceInHeadMode_Bypass: Self