AUSpatialMixerSourceMode

Struct AUSpatialMixerSourceMode 

#[repr(transparent)]
pub struct AUSpatialMixerSourceMode(pub u32);
Available on crate feature AudioUnitProperties only.
Mono input is spatialized using kAudioUnitProperty_SpatializationAlgorithm. Any input with more than one channel is passed through without spatialization. This is the default mode and corresponds to legacy behavior. The rendering is equivalent to kSpatialMixerSourceMode_PointSource for mono input and kSpatialMixerSourceMode_Bypass for input with more than one channel.

No spatial rendering. If input and output AudioChannelLayouts are equivalent, all input channels are copied to corresponding output channels. If the input and output AudioChannelLayouts differ, mixing is done according to the kAudioFormatProperty_MatrixMixMap property of the layouts. No occlusion, obstruction, or reverb is applied in this mode.

All channels of the input signal are rendered as a single source except if rendering in-head with kSpatialMixerPointSourceInHeadMode_Bypass.

The input channels are spatialized around the listener as far-field sources. The relative directions of the individual channels are specified by the AudioChannelLayout of the bus. The rotation of the whole bed in the global space is controlled by azimuth and elevation parameters.

See also Apple’s documentation

Tuple Fields

0: u32

Implementations