#[repr(C)]pub struct AUVoiceIOOtherAudioDuckingConfiguration {
pub mEnableAdvancedDucking: u8,
pub mDuckingLevel: AUVoiceIOOtherAudioDuckingLevel,
}Available on crate feature
AudioUnitProperties only.Expand description
The configuration of ducking other (i.e. non-voice) audio
Enables advanced ducking which ducks other audio based on the presence of voice activity from local and/or remote chat participants.
Ducking level of other audio
See also Apple’s documentation
Fields
mEnableAdvancedDucking: u8mDuckingLevel: AUVoiceIOOtherAudioDuckingLevelTrait Implementations
Sourceimpl Clone for AUVoiceIOOtherAudioDuckingConfiguration
impl Clone for AUVoiceIOOtherAudioDuckingConfiguration
Sourcefn clone(&self) -> AUVoiceIOOtherAudioDuckingConfiguration
fn clone(&self) -> AUVoiceIOOtherAudioDuckingConfiguration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for AUVoiceIOOtherAudioDuckingConfiguration
impl PartialEq for AUVoiceIOOtherAudioDuckingConfiguration
Sourcefn eq(&self, other: &AUVoiceIOOtherAudioDuckingConfiguration) -> bool
fn eq(&self, other: &AUVoiceIOOtherAudioDuckingConfiguration) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RefEncode for AUVoiceIOOtherAudioDuckingConfiguration
impl RefEncode for AUVoiceIOOtherAudioDuckingConfiguration
Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl Copy for AUVoiceIOOtherAudioDuckingConfiguration
impl StructuralPartialEq for AUVoiceIOOtherAudioDuckingConfiguration