AudioConverterPrimeInfo

Struct AudioConverterPrimeInfo 

#[repr(C)]
pub struct AudioConverterPrimeInfo { pub leadingFrames: u32, pub trailingFrames: u32, }
Available on crate feature AudioConverter only.
Specifies priming information.

When using AudioConverterFillComplexBuffer() (either a single call or a series of calls), some conversions, particularly involving sample-rate conversion, ideally require a certain number of input frames previous to the normal start input frame and beyond the end of the last expected input frame in order to yield high-quality results.

These are expressed in the leadingFrames and trailingFrames members of the structure.

The very first call to AudioConverterFillComplexBuffer(), or first call after AudioConverterReset(), will request additional input frames beyond those normally expected in the input proc callback to fulfill this first AudioConverterFillComplexBuffer() request. The number of additional frames requested, depending on the prime method, will be approximately:

Prime methodAdditional frames
kConverterPrimeMethod_PreleadingFrames + trailingFrames
kConverterPrimeMethod_NormaltrailingFrames
kConverterPrimeMethod_None0

Thus, in effect, the first input proc callback(s) may provide not only the leading frames, but also may “read ahead” by an additional number of trailing frames depending on the prime method.

kConverterPrimeMethod_None is useful in a real-time application processing live input, in which case trailingFrames (relative to input sample rate) of through latency will be seen at the beginning of the output of the AudioConverter. In other real-time applications such as DAW systems, it may be possible to provide these initial extra audio frames since they are stored on disk or in memory somewhere and kConverterPrimeMethod_Pre may be preferable. The default method is kConverterPrimeMethod_Normal, which requires no pre-seeking of the input stream and generates no latency at the output.

Specifies the number of leading (previous) input frames, relative to the normal/desired start input frame, required by the converter to perform a high quality conversion. If using kConverterPrimeMethod_Pre, the client should “pre-seek” the input stream provided through the input proc by leadingFrames. If no frames are available previous to the desired input start frame (because, for example, the desired start frame is at the very beginning of available audio), then provide “leadingFrames” worth of initial zero frames in the input proc. Do not “pre-seek” in the default case of kConverterPrimeMethod_Normal or when using kConverterPrimeMethod_None.

Specifies the number of trailing input frames (past the normal/expected end input frame) required by the converter to perform a high quality conversion. The client should be prepared to provide this number of additional input frames except when using kConverterPrimeMethod_None. If no more frames of input are available in the input stream (because, for example, the desired end frame is at the end of an audio file), then zero (silent) trailing frames will be synthesized for the client.

See also Apple’s documentation

Fields

leadingFrames: u32trailingFrames: u32