#[repr(C)]pub struct AudioPanningInfo {
pub mPanningMode: AudioPanningMode,
pub mCoordinateFlags: u32,
pub mCoordinates: [f32; 3],
pub mGainScale: f32,
pub mOutputChannelMap: NonNull<AudioChannelLayout>,
}Available on crate features
AudioFormat and objc2-core-audio-types only.Expand description
This struct is for use with kAudioFormatProperty_PanningMatrix.
mGainScale is used to multiply the panning values. In typical usage you are applying an existing volume. value in 0 -> 1 (where 1 is unity gain) to the panned values. 1 would give you panning at unity. 0 would give you back a matrix of zeroes.
This is the channel map that is going to be used to determine channel volumes for this pan.
See also Apple’s documentation
Fields
mPanningMode: AudioPanningModemCoordinateFlags: u32mCoordinates: [f32; 3]mGainScale: f32mOutputChannelMap: NonNull<AudioChannelLayout>Trait Implementations
Sourceimpl Clone for AudioPanningInfo
impl Clone for AudioPanningInfo
Sourcefn clone(&self) -> AudioPanningInfo
fn clone(&self) -> AudioPanningInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AudioPanningInfo
impl Debug for AudioPanningInfo
Sourceimpl Encode for AudioPanningInfo
impl Encode for AudioPanningInfo
Sourceimpl PartialEq for AudioPanningInfo
impl PartialEq for AudioPanningInfo
Sourceimpl RefEncode for AudioPanningInfo
impl RefEncode for AudioPanningInfo
Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl Copy for AudioPanningInfo
impl StructuralPartialEq for AudioPanningInfo