AudioUnitMeterClipping

Struct AudioUnitMeterClipping 

#[repr(C)]
pub struct AudioUnitMeterClipping { pub peakValueSinceLastCall: f32, pub sawInfinity: u8, pub sawNotANumber: u8, }
Available on crate feature AudioUnitProperties only.
The maximum value seen on the channel since the last time the property was retrieved.

TRUE if there was an infinite value on this channel.

TRUE if there was a floating point Not-A-Number value on this channel.

See also Apple’s documentation

Fields

peakValueSinceLastCall: f32sawInfinity: u8sawNotANumber: u8