#[repr(C)]pub struct AudioUnitOtherPluginDesc {
pub format: u32,
pub plugin: AudioClassDescription,
}Available on crate features
AudioUnitProperties and objc2-core-audio-types only.Expand description
One of the OtherPluginFormat values
struct AudioClassDescription { OSType mType; OSType mSubType; OSType mManufacturer; }; is defined in <CoreAudioTypes /CoreAudioTypes.h>
mType specifies a generic, plug-in format defined descriptor mSubType is usually left to the manufacturer to use at their discretion mManufacturer is a registered code to identify all plugins from the same manufacturer
See also Apple’s documentation
Fields
format: u32plugin: AudioClassDescriptionTrait Implementations
Sourceimpl Clone for AudioUnitOtherPluginDesc
impl Clone for AudioUnitOtherPluginDesc
Sourcefn clone(&self) -> AudioUnitOtherPluginDesc
fn clone(&self) -> AudioUnitOtherPluginDesc
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AudioUnitOtherPluginDesc
impl Debug for AudioUnitOtherPluginDesc
Sourceimpl Encode for AudioUnitOtherPluginDesc
impl Encode for AudioUnitOtherPluginDesc
Sourceimpl PartialEq for AudioUnitOtherPluginDesc
impl PartialEq for AudioUnitOtherPluginDesc
Sourceimpl RefEncode for AudioUnitOtherPluginDesc
impl RefEncode for AudioUnitOtherPluginDesc
Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl Copy for AudioUnitOtherPluginDesc
impl StructuralPartialEq for AudioUnitOtherPluginDesc