#[repr(C)]pub struct AudioUnitParameterValueFromString {
pub inParamID: AudioUnitParameterID,
pub inString: NonNull<CFString>,
pub outValue: AudioUnitParameterValue,
}Available on crate features
AUComponent and AudioUnitProperties and objc2-core-foundation only.Expand description
Provide the parameter’s value for a given string representation of it
See also Apple’s documentation
Fields
inParamID: AudioUnitParameterIDinString: NonNull<CFString>outValue: AudioUnitParameterValueTrait Implementations
Sourceimpl Clone for AudioUnitParameterValueFromString
impl Clone for AudioUnitParameterValueFromString
Sourcefn clone(&self) -> AudioUnitParameterValueFromString
fn clone(&self) -> AudioUnitParameterValueFromString
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for AudioUnitParameterValueFromString
impl PartialEq for AudioUnitParameterValueFromString
Sourcefn eq(&self, other: &AudioUnitParameterValueFromString) -> bool
fn eq(&self, other: &AudioUnitParameterValueFromString) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RefEncode for AudioUnitParameterValueFromString
impl RefEncode for AudioUnitParameterValueFromString
Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl Copy for AudioUnitParameterValueFromString
impl StructuralPartialEq for AudioUnitParameterValueFromString