AUImplementorDisplayNameWithLengthCallback

Type Alias AUImplementorDisplayNameWithLengthCallback 

pub type AUImplementorDisplayNameWithLengthCallback = *mut DynBlock<dyn Fn(NonNull<AUParameterNode>, NSInteger) -> NonNull<NSString>>;
Available on crate features AUAudioUnitImplementation and AUParameters and block2 only.
A block called to return a group or parameter’s localized display name, abbreviated to the requested length.

See also Apple’s documentation