AUInputHandler

Type Alias AUInputHandler 

pub type AUInputHandler = *mut DynBlock<dyn Fn(NonNull<AudioUnitRenderActionFlags>, NonNull<AudioTimeStamp>, AUAudioFrameCount, NSInteger)>;
Available on crate features AUAudioUnit and AUComponent and block2 and objc2-core-audio-types only.
Block to notify the client of an I/O unit that input is available.

Parameter actionFlags: Pointer to action flags.

Parameter timestamp: The HAL time at which the input data was captured. If there is a sample rate conversion or time compression/expansion downstream, the sample time will not be valid.

Parameter frameCount: The number of sample frames of input available.

Parameter inputBusNumber: The index of the input bus from which input is available.

The input data is obtained by calling the render block of the audio unit. The AUAudioUnit is not provided since it is not safe to message an Objective C object in a real time context.

See also Apple’s documentation