pub type AUInputSamplesInOutputCallback = Option<unsafe extern "C-unwind" fn(NonNull<c_void>, NonNull<AudioTimeStamp>, f64, f64)>;Available on crate features
AUComponent and objc2-core-audio-types only.Expand description
This is the prototype for a function callback Proc that is registered with an audio unit to notify the caller of for the user of a varispeed or AUTimePitch audio unit where it is not clear what input sample is represented in the rendered output samples.
Parameter inRefCon: The client data that is provided with the add property listener registration
Parameter inOutputTimeStamp: The time stamp that corresponds to the first sample of audio data produced in
AudioUnitRender (its output data)
Parameter inInputSample: The sample number of the input that is represented in the first sample of that
output time stamp
Parameter inNumberInputSamples: The number of input samples that are represented in an output buffer
See also Apple’s documentation
Aliased Type
pub enum AUInputSamplesInOutputCallback {
None,
Some(unsafe extern "C-unwind" fn(NonNull<c_void>, NonNull<AudioTimeStamp>, f64, f64)),
}