pub type AUParameterAddress = u64;Available on crate feature
AUParameters only.Expand description
Numeric identifier for audio unit parameter.
Note that parameter addresses are not necessarily persistent, unless the individual audio unit documents a promise to maintain its addressing scheme. Hosts should bind to parameters’ key paths.
See also Apple’s documentation