AURenderPullInputBlock

Type Alias AURenderPullInputBlock 

pub type AURenderPullInputBlock = *mut DynBlock<dyn Fn(NonNull<AudioUnitRenderActionFlags>, NonNull<AudioTimeStamp>, AUAudioFrameCount, NSInteger, NonNull<AudioBufferList>) -> AUAudioUnitStatus>;
Available on crate features AUAudioUnit and AUComponent and block2 and objc2-core-audio-types only.
Block to supply audio input to AURenderBlock.

Parameter actionFlags: Pointer to action flags.

Parameter timestamp: The HAL time at which the input data will be rendered. If there is a sample rate conversion or time compression/expansion downstream, the sample time will not be valid.

Parameter frameCount: The number of sample frames of input requested.

Parameter inputBusNumber: The index of the input bus being pulled.

Parameter inputData: The input audio data.

The caller must supply valid buffers in inputData’s mBuffers’ mData and mDataByteSize. mDataByteSize must be consistent with frameCount. This block may provide input in those specified buffers, or it may replace the mData pointers with pointers to memory which it owns and guarantees will remain valid until the next render cycle.

Returns: An AUAudioUnitStatus result code. If an error is returned, the input data should be assumed to be invalid.

See also Apple’s documentation