AudioFile_ReadProc

Type Alias AudioFile_ReadProc 

pub type AudioFile_ReadProc = Option<unsafe extern "C-unwind" fn(NonNull<c_void>, i64, u32, NonNull<c_void>, NonNull<u32>) -> i32>;
Available on crate feature AudioFile only.
A callback for reading data. used with AudioFileOpenWithCallbacks or AudioFileInitializeWithCallbacks.

a function that will be called when AudioFile needs to read data.

Parameter inClientData: A pointer to the client data as set in the inClientData parameter to AudioFileXXXWithCallbacks.

Parameter inPosition: An offset into the data from which to read.

Parameter requestCount: The number of bytes to read.

Parameter buffer: The buffer in which to put the data read.

Parameter actualCount: The callback should set this to the number of bytes successfully read.

Returns: The callback should return noErr on success, or an appropriate error code on failure.

See also Apple’s documentation

Aliased Type

pub enum AudioFile_ReadProc {
    None,
    Some(unsafe extern "C-unwind" fn(NonNull<c_void>, i64, u32, NonNull<c_void>, NonNull<u32>) -> i32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C-unwind" fn(NonNull<c_void>, i64, u32, NonNull<c_void>, NonNull<u32>) -> i32)

Some value of type T.