pub type AudioFile_WriteProc = Option<unsafe extern "C-unwind" fn(NonNull<c_void>, i64, u32, NonNull<c_void>, NonNull<u32>) -> i32>;Available on crate feature
AudioFile only.Expand description
A callback for writing data. used with AudioFileOpenWithCallbacks or AudioFileInitializeWithCallbacks.
a function that will be called when AudioFile needs to write data.
Parameter inClientData: A pointer to the client data as set in the inClientData parameter to AudioFileXXXWithCallbacks.
Parameter inPosition: An offset into the data from which to read.
Parameter requestCount: The number of bytes to write.
Parameter buffer: The buffer containing the data to write.
Parameter actualCount: The callback should set this to the number of bytes successfully written.
Returns: The callback should return noErr on success, or an appropriate error code on failure.
See also Apple’s documentation
Aliased Type
pub enum AudioFile_WriteProc {
None,
Some(unsafe extern "C-unwind" fn(NonNull<c_void>, i64, u32, NonNull<c_void>, NonNull<u32>) -> i32),
}