AudioQueueOutputCallback

Type Alias AudioQueueOutputCallback 

pub type AudioQueueOutputCallback = Option<unsafe extern "C-unwind" fn(*mut c_void, AudioQueueRef, AudioQueueBufferRef)>;
Available on crate features AudioQueue and objc2-core-audio-types only.
Defines a pointer to a callback function that is called when a playback audio queue has finished taking data from a buffer.

A playback buffer callback is invoked when the audio queue has finished with the data to be played and the buffer is available to your application for reuse. Your application might want to immediately refill and re-enqueue the completed buffer at this time.

Parameter inUserData: The value specified by the inUserData parameter of the AudioQueueNewOutput function.

Parameter inAQ: The audio queue that invoked the callback.

Parameter inBuffer: The audio queue buffer made available by the audio queue.

See also Apple’s documentation

Aliased Type

pub enum AudioQueueOutputCallback {
    None,
    Some(unsafe extern "C-unwind" fn(*mut c_void, *mut OpaqueAudioQueue, *mut AudioQueueBuffer)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C-unwind" fn(*mut c_void, *mut OpaqueAudioQueue, *mut AudioQueueBuffer))

Some value of type T.