pub type AudioQueueParameterID = u32;Available on crate feature
AudioQueue only.Expand description
A value that uniquely identifies an audio queue parameter.
See also Appleās documentation
pub type AudioQueueParameterID = u32;AudioQueue only.A value that uniquely identifies an audio queue parameter.
See also Appleās documentation