pub type AudioQueuePropertyID = u32;Available on crate feature
AudioQueue only.Expand description
A value that uniquely identifies an audio queue property.
See also Appleās documentation
pub type AudioQueuePropertyID = u32;AudioQueue only.A value that uniquely identifies an audio queue property.
See also Appleās documentation