pub type AudioQueueRef = *mut OpaqueAudioQueue;Available on crate feature
AudioQueue only.Expand description
An opaque data type that represents an audio queue.
See also Appleās documentation
pub type AudioQueueRef = *mut OpaqueAudioQueue;AudioQueue only.An opaque data type that represents an audio queue.
See also Appleās documentation