pub type AudioQueueTimelineRef = *mut OpaqueAudioQueueTimeline;Available on crate feature
AudioQueue only.Expand description
An opaque data type that represents an audio queue timeline.
You can use this object to observe any overloads in the audio device associated with the audio queue. A timeline object receives notifications of discontinuities in the audio hardware’s sample timeline–for instance, a period of silence when sound was expected. Causes of discontinuities include changes in the device state or processing overloads. See Technical Q & A: QA 1467 for a discussion of Core Audio overload warnings. These warnings indicate you are taking too long to process audio data and the system has cut you off. You query a timeline object by passing it as a parameter to AudioQueueGetCurrentTime, which means a discontinuity has occurred.
See also Apple’s documentation