AudioUnitGetParameterProc

Type Alias AudioUnitGetParameterProc 

pub type AudioUnitGetParameterProc = Option<unsafe extern "C-unwind" fn(NonNull<c_void>, AudioUnitParameterID, AudioUnitScope, AudioUnitElement, NonNull<AudioUnitParameterValue>) -> i32>;
Available on crate feature AUComponent only.
This proc can be exported through the FastDispatch property or is used as the prototype for an audio component dispatch for this selector.

The arguments are the same as are provided to the corresponding API call

Parameter inComponentStorage: For a component manager component, this is the component instance storage pointer

See also Apple’s documentation

Aliased Type

pub enum AudioUnitGetParameterProc {
    None,
    Some(unsafe extern "C-unwind" fn(NonNull<c_void>, u32, u32, u32, NonNull<f32>) -> i32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C-unwind" fn(NonNull<c_void>, u32, u32, u32, NonNull<f32>) -> i32)

Some value of type T.