CallHostBlock

Type Alias CallHostBlock 

pub type CallHostBlock = *mut DynBlock<dyn Fn(NonNull<NSDictionary>) -> NonNull<NSDictionary>>;
Available on crate features AUAudioUnit and block2 only.
Block that hosts provide to AU message channels to be called back by the AU.

Parameter message: An NSDictionary with custom data. The allowed classes for key and value types are NSArray, NSDictionary, NSOrderedSet, NSSet, NSString, NSData, NSNull, NSNumber, NSDate

Returns: An NSDictionary with custom data. The allowed classes for key and value types are NSArray, NSDictionary, NSOrderedSet, NSSet, NSString, NSData, NSNull, NSNumber, NSDate

See also Apple’s documentation