MusicDeviceStartNoteProc

Type Alias MusicDeviceStartNoteProc 

pub type MusicDeviceStartNoteProc = Option<unsafe extern "C-unwind" fn(NonNull<c_void>, MusicDeviceInstrumentID, MusicDeviceGroupID, NonNull<NoteInstanceID>, u32, NonNull<MusicDeviceNoteParams>) -> i32>;
Available on crate features AUComponent and MusicDevice only.
This proc can be exported through the FastDispatch property or is used as the prototype for an audio component dispatch for this selector.

The arguments are the same as are provided to the corresponding API call

Parameter self: For a component manager component, this is the component instance storage pointer

Returns: noErr, or an audio unit error code

See also Apple’s documentation

Aliased Type

pub enum MusicDeviceStartNoteProc {
    None,
    Some(unsafe extern "C-unwind" fn(NonNull<c_void>, u32, u32, NonNull<u32>, u32, NonNull<MusicDeviceNoteParams>) -> i32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C-unwind" fn(NonNull<c_void>, u32, u32, NonNull<u32>, u32, NonNull<MusicDeviceNoteParams>) -> i32)

Some value of type T.