NoteInstanceID

Type Alias NoteInstanceID 

pub type NoteInstanceID = u32;
Available on crate feature MusicDevice only.
The type used to hold an unique identifier returned by MusicDeviceStartNote that is used to then address that note (typically to turn the note off). An ID must be used for notes, because notes can be specified by fractional pitches, and so using the MIDI note number is not sufficient to identify the note to turn it off (or to apply polyphonic after touch).

See also Apple’s documentation