pub unsafe extern "C-unwind" fn AUGraphGetMaxCPULoad(
in_graph: AUGraph,
out_max_load: NonNull<f32>,
) -> i32๐Deprecated: AUGraph is deprecated in favor of AVAudioEngine
Available on crate feature
AUGraph only.Expand description
The Maximum CPU load of the graph
Returns the max CPU load of the graph since this call was last made or the graph was last started.
Safety
in_graphmust be a valid pointer.out_max_loadmust be a valid pointer.