pub unsafe extern "C-unwind" fn AUGraphInitialize(
in_graph: AUGraph,
) -> i32๐Deprecated: AUGraph is deprecated in favor of AVAudioEngine
Available on crate feature
AUGraph only.Expand description
Initialise a graph
AudioUnitInitialize() is called on each opened node/AudioUnit (get ready to render) and SubGraph that are involved in a interaction. If the node is not involved, it is initialised after it becomes involved in an interaction.
A graph must be opened before it can be initialised.
Safety
in_graph must be a valid pointer.