pub unsafe extern "C-unwind" fn AUParameterListenerNotify(
in_sending_listener: AUParameterListenerRef,
in_sending_object: *mut c_void,
in_parameter: NonNull<AudioUnitParameter>,
) -> i32AUComponent and AudioComponent and AudioUnitUtilities only.Expand description
Notify listeners of a past parameter change.
Parameter inSendingListener: A parameter listener generating the change and which does not want to
receive a callback as a result of it. May be NULL.
Parameter inSendingObject: The object generating the change and which does not want to receive a
callback as a result of it. NULL is treated specially when inListener is
non-null; it signifies that none of the specified listener’s objects will
receive notifications.
Parameter inParameter: The parameter which was changed.
Performs and schedules the notification callbacks of AUParameterSet, without actually setting an AudioUnit parameter value.
Clients scheduling ramped parameter changes to AudioUnits must make this call dynamically during playback in order for AudioUnitViews to be updated. When the view’s listener receives a notification, it will be passed the current value of the parameter.
A special meaning is applied if the mParameterID value of inParameter is equal to kAUParameterListener_AnyParameter. In this case, ANY listener for ANY parameter value changes on the specified AudioUnit will be notified of the current value of that parameter.
Safety
in_sending_listenermust be a valid pointer or null.in_sending_objectmust be a valid pointer or null.in_parametermust be a valid pointer.