pub unsafe extern "C-unwind" fn AUParameterSet(
in_sending_listener: AUParameterListenerRef,
in_sending_object: *mut c_void,
in_parameter: NonNull<AudioUnitParameter>,
in_value: AudioUnitParameterValue,
in_buffer_offset_in_frames: u32,
) -> i32AUComponent and AudioComponent and AudioUnitUtilities only.Expand description
Set an AudioUnit parameter value and notify listeners.
Parameter inSendingListener: A parameter listener generating the change and which does not want to
receive a callback as a result of it. May be NULL.
Parameter inSendingObject: The object generating the change and which does not want to receive a
callback as a result of it. NULL is treated specially when inListener is
non-null; it signifies that none of the specified listener’s objects will
receive notifications.
Parameter inParameter: The parameter being changed.
Parameter inValue: The new value of the parameter.
Parameter inBufferOffsetInFrames: The offset into the next rendered buffer at which the parameter change will take
effect.
Calls AudioUnitSetParameter, and performs/schedules notification callbacks to all parameter listeners, for that parameter – except that no callback will be generated to the inListener/inObject pair.
Safety
in_sending_listenermust be a valid pointer or null.in_sending_objectmust be a valid pointer or null.in_parametermust be a valid pointer.