pub unsafe extern "C-unwind" fn AudioCodecGetPropertyInfo(
in_codec: AudioCodec,
in_property_id: AudioCodecPropertyID,
out_size: *mut u32,
out_writable: *mut u8,
) -> i32Available on crate features
AudioCodec and AudioComponent only.Expand description
Retrieve information about the given property. The outSize argument will return the size in bytes of the current value of the property. The outWritable argument will return whether or not the property in question can be changed.
Parameter inCodec: An AudioCodec instance
Parameter inPropertyID: Property ID whose value should be read
Parameter outSize: Size in bytes of the property
Parameter outWritable: Flag indicating wether the underlying property can be modified or not
Returns: The OSStatus value
Safety
in_codecmust be a valid pointer.out_sizemust be a valid pointer or null.out_writablemust be a valid pointer or null.