pub unsafe extern "C-unwind" fn AudioCodecInitialize(
in_codec: AudioCodec,
in_input_format: *const AudioStreamBasicDescription,
in_output_format: *const AudioStreamBasicDescription,
in_magic_cookie: *const c_void,
in_magic_cookie_byte_size: u32,
) -> i32Available on crate features
AudioCodec and AudioComponent and objc2-core-audio-types only.Expand description
This call will allocate any buffers needed and otherwise set the codec up to perform the indicated translation. If an argument is NULL, any previously set properties will be used for preparing the codec for work. Note that this routine will also validate the format information as useable.
Parameter inCodec: An AudioCodec instance
Parameter inInputFormat: Pointer to an input format structure
Parameter inOutputFormat: Pointer to an output format structure
Parameter inMagicCookie: Pointer to the magic cookie
Parameter inMagicCookieByteSize: Size in bytes of the magic cookie
Returns: The OSStatus value
Safety
in_codecmust be a valid pointer.in_input_formatmust be a valid pointer or null.in_output_formatmust be a valid pointer or null.in_magic_cookiemust be a valid pointer or null.