pub unsafe extern "C-unwind" fn AudioCodecReset(
in_codec: AudioCodec,
) -> i32Available on crate features
AudioCodec and AudioComponent only.Expand description
Flushes all the data in the codec and clears the input buffer. Note that the formats, and magic cookie will be retained so they won’t need to be set up again to decode the same data.
Parameter inCodec: The audio codec descriptor
Returns: the OSStatus value
Safety
in_codec must be a valid pointer.