pub unsafe extern "C-unwind" fn AudioComponentCount(
in_desc: NonNull<AudioComponentDescription>,
) -> u32Available on crate feature
AudioComponent only.Expand description
Counts audio components.
Returns the number of AudioComponents that match the specified AudioComponentDescription.
Parameter inDesc: The type, subtype and manufacturer fields are used to specify the audio
components to count A value of 0 (zero) for any of these fields is a
wildcard, so will match any value for this field
Returns: a UInt32. 0 (zero) means no audio components were found that matched the search parameters.
Safety
in_desc must be a valid pointer.