pub unsafe extern "C-unwind" fn AudioComponentInstanceCanDo(
in_instance: AudioComponentInstance,
in_selector_id: i16,
) -> boolAvailable on crate feature
AudioComponent only.Expand description
Determines if an audio component instance implements a particular component API call as signified by the specified selector identifier token.
Parameter inInstance: the audio component instance
Parameter inSelectorID: a number to signify the audio component API (component selector) as appropriate for the instance’s component type.
Returns: a boolean
Safety
in_instance must be a valid pointer.