pub unsafe extern "C-unwind" fn AudioComponentInstanceNew(
in_component: AudioComponent,
out_instance: NonNull<AudioComponentInstance>,
) -> i32Available on crate feature
AudioComponent only.Expand description
Creates an audio component instance.
This function creates an instance of a given audio component. The audio component instance is the object that does all of the work, whereas the audio component is the way an application finds and then creates this object to do this work. For example, an audio unit is a type of audio component instance, so to use an audio unit, one finds its audio component, and then creates a new instance of that component. This instance is then used to perform the audio tasks for which it was designed (process, mix, synthesise, etc.).
Parameter inComponent: the audio component (must not be NULL)
Parameter outInstance: the audio component instance
Returns: an OSStatus result code.
Safety
in_componentmust be a valid pointer.out_instancemust be a valid pointer.