pub unsafe extern "C-unwind" fn AudioComponentRegister(
in_desc: NonNull<AudioComponentDescription>,
in_name: &CFString,
in_version: u32,
in_factory: AudioComponentFactoryFunction,
) -> AudioComponentAudioComponent and objc2-core-foundation only.Expand description
Dynamically registers an AudioComponent within the current process
AudioComponents are registered either when found in appropriate bundles in the filesystem, or via this call. AudioComponents registered via this call are available only within the current process.
Parameter inDesc: The AudioComponentDescription that describes the AudioComponent. Note that
the registrar needs to be sure to set the flag kAudioComponentFlag_SandboxSafe
in the componentFlags field of the AudioComponentDescription to indicate that
the AudioComponent can be loaded directly into a sandboxed process.
Parameter inName: the AudioComponent’s name
Parameter inVersion: the AudioComponent’s version
Parameter inFactory: an AudioComponentFactoryFunction which will create instances of your
AudioComponent
Returns: an AudioComponent object
Safety
in_descmust be a valid pointer.in_factorymust be implemented correctly.