pub unsafe extern "C-unwind" fn AudioFileGetGlobalInfo(
in_property_id: AudioFilePropertyID,
in_specifier_size: u32,
in_specifier: *mut c_void,
io_data_size: NonNull<u32>,
out_property_data: NonNull<c_void>,
) -> i32Available on crate feature
AudioFile only.Expand description
Copies the value for a global property into a buffer.
Parameter inPropertyID: an AudioFileGlobalInfo property constant.
Parameter inSpecifierSize: The size of the specifier data.
Parameter inSpecifier: A specifier is a buffer of data used as an input argument to some of the global info properties.
Parameter ioDataSize: on input the size of the outPropertyData buffer. On output the number of bytes written to the buffer.
Parameter outPropertyData: the buffer in which to write the property data.
Returns: returns noErr if successful.
Safety
in_specifiermust be a valid pointer or null.io_data_sizemust be a valid pointer.out_property_datamust be a valid pointer.