pub unsafe extern "C-unwind" fn AudioFileGetPropertyInfo(
in_audio_file: AudioFileID,
in_property_id: AudioFilePropertyID,
out_data_size: *mut u32,
is_writable: *mut u32,
) -> i32Available on crate feature
AudioFile only.Expand description
Get information about the size of a property of an AudioFile and whether it can be set.
Parameter inAudioFile: an AudioFileID.
Parameter inPropertyID: an AudioFileProperty constant.
Parameter outDataSize: the size in bytes of the current value of the property. In order to get the property value,
you will need a buffer of this size.
Parameter isWritable: will be set to 1 if writable, or 0 if read only.
Returns: returns noErr if successful.
Safety
in_audio_filemust be a valid pointer.out_data_sizemust be a valid pointer or null.is_writablemust be a valid pointer or null.