pub unsafe extern "C-unwind" fn AudioFileWriteBytes(
in_audio_file: AudioFileID,
in_use_cache: bool,
in_starting_byte: i64,
io_num_bytes: NonNull<u32>,
in_buffer: NonNull<c_void>,
) -> i32Available on crate feature
AudioFile only.Expand description
Write bytes of audio data to the audio file.
Parameter inAudioFile: an AudioFileID.
Parameter inUseCache: true if it is desired to cache the data upon write, else false
Parameter inStartingByte: the byte offset where the audio data should be written
Parameter ioNumBytes: on input, the number of bytes to write, on output, the number of
bytes actually written.
Parameter inBuffer: inBuffer should be a void * containing the bytes to be written
Returns: returns noErr if successful.
Safety
in_audio_filemust be a valid pointer.io_num_bytesmust be a valid pointer.in_buffermust be a valid pointer.