pub unsafe extern "C-unwind" fn AudioFormatGetPropertyInfo(
in_property_id: AudioFormatPropertyID,
in_specifier_size: u32,
in_specifier: *const c_void,
out_property_data_size: NonNull<u32>,
) -> i32Available on crate feature
AudioFormat only.Expand description
Retrieve information about the given property
Parameter inPropertyID: an AudioFormatPropertyID constant.
Parameter inSpecifierSize: The size of the specifier data.
Parameter inSpecifier: A specifier is a buffer of data used as an input argument to some of the properties.
Parameter outPropertyDataSize: The size in bytes of the current value of the property. In order to get the property value,
you will need a buffer of this size.
Returns: returns noErr if successful.
Safety
in_specifiermust be a valid pointer or null.out_property_data_sizemust be a valid pointer.