pub unsafe extern "C-unwind" fn AudioHardwareServiceIsPropertySettable(
in_object_id: AudioObjectID,
in_address: *const AudioObjectPropertyAddress,
out_is_settable: *mut u8,
) -> i32๐Deprecated: no longer supported
Available on crate feature
objc2-core-audio only.Expand description
Queries an AudioObject about whether or not the given property can be set using AudioHardwareServiceSetPropertyData.
Parameter inObjectID: The AudioObject to query.
Parameter inAddress: An AudioObjectPropertyAddress indicating which property is being queried.
Parameter outIsSettable: A Boolean indicating whether or not the property can be set.
Returns: An OSStatus indicating success or failure.
Safety
in_addressmust be a valid pointer.out_is_settablemust be a valid pointer.