pub unsafe extern "C-unwind" fn AudioHardwareServiceRemovePropertyListener(
in_object_id: AudioObjectID,
in_address: *const AudioObjectPropertyAddress,
in_listener: AudioObjectPropertyListenerProc,
in_client_data: *mut c_void,
) -> i32๐Deprecated: no longer supported
Available on crate feature
objc2-core-audio only.Expand description
Unregisters the given AudioObjectPropertyListenerProc from receiving notifications when the given properties change.
Parameter inObjectID: The AudioObject to unregister the listener from.
Parameter inAddress: The AudioObjectPropertyAddresses indicating which property the listener
will stop being notified about.
Parameter inListener: The AudioObjectPropertyListenerProc being removed.
Parameter inClientData: A pointer to client data that is passed to the listener when it is called.
Returns: An OSStatus indicating success or failure.
Safety
in_addressmust be a valid pointer.in_listenermust be implemented correctly.in_client_datamust be a valid pointer.