pub unsafe extern "C-unwind" fn AudioQueueDispose(
in_aq: AudioQueueRef,
in_immediate: bool,
) -> i32AudioQueue only.Expand description
Disposes an existing audio queue.
Disposing of the audio queue also disposes of all its resources, including its buffers.
Parameter inAQ: The audio queue you want to dispose of
Parameter inImmediate: If you pass true, the audio queue is disposed of immediately (that is, synchronously).
If you pass false, disposal does not take place until all enqueued buffers are
processed. Whether you call AudioQueueDispose synchronously or asynchronously, you can
no longer interact with the queue, and the queue no longer invokes any callbacks to your
application after the function returns.
Note that if AudioQueueDispose is called from a buffer completion callback or property listener, you may receive further callbacks afterwards.
Returns: An OSStatus result code.
Safety
in_aq must be a valid pointer.