pub unsafe extern "C-unwind" fn AudioQueueDisposeTimeline(
in_aq: AudioQueueRef,
in_timeline: AudioQueueTimelineRef,
) -> i32Available on crate feature
AudioQueue only.Expand description
Disposes of a timeline object.
Disposing of an audio queue automatically disposes of any associated timeline objects. Call this function only if you want to dispose of a timeline object and not the audio queue associated with it.
Parameter inAQ: The audio queue associated with the timeline object you want to dispose of.
Parameter inTimeline: The timeline object to dispose of.
Returns: An OSStatus result code.
Safety
in_aqmust be a valid pointer.in_timelinemust be a valid pointer.