pub unsafe extern "C-unwind" fn AudioQueueFreeBuffer(
in_aq: AudioQueueRef,
in_buffer: AudioQueueBufferRef,
) -> i32Available on crate features
AudioQueue and objc2-core-audio-types only.Expand description
Disposes of an audio queue buffer.
This function disposes of the buffer allocated by AudioQueueAllocateBuffer. Disposing of an audio queue also automatically disposes of any associated buffers and timeline objects. Call this function only if you want to dispose of a particular buffer while continuing to use an audio queue. You can dispose of buffers only when the associated queue is stopped (that is, not processing audio data).
Parameter inAQ: The queue from which the buffer was allocated.
Parameter inBuffer: The buffer to be disposed.
Returns: An OSStatus result code.
Safety
in_aqmust be a valid pointer.in_buffermust be a valid pointer.