pub unsafe extern "C-unwind" fn AudioQueueGetProperty(
in_aq: AudioQueueRef,
in_id: AudioQueuePropertyID,
out_data: NonNull<c_void>,
io_data_size: NonNull<u32>,
) -> i32Available on crate feature
AudioQueue only.Expand description
Obtains an audio queue property value.
Parameter inAQ: The audio queue whose property value you want to obtain.
Parameter inID: The ID of the property you want to obtain. See “Audio Queue Property IDs.”
Parameter outData: On return, points to the desired property value.
Parameter ioDataSize: A pointer to the size of the property data. On input, points to the maximum bytes of
space the caller expects to receive. On return, points to the actual data size.
Returns: An OSStatus result code.
Safety
in_aqmust be a valid pointer.out_datamust be a valid pointer.io_data_sizemust be a valid pointer.