pub unsafe extern "C-unwind" fn AudioQueueRemovePropertyListener(
in_aq: AudioQueueRef,
in_id: AudioQueuePropertyID,
in_proc: AudioQueuePropertyListenerProc,
in_user_data: *mut c_void,
) -> i32Available on crate feature
AudioQueue only.Expand description
Removes a listener callback for a property.
Parameter inAQ: The audio queue that owns the property from which you want to remove a listener.
Parameter inID: The ID of the property from which you want to remove a listener.
Parameter inProc: The listener being removed.
Parameter inUserData: The same inUserData value that was previously passed to AudioQueueAddPropertyListener.
Returns: An OSStatus result code.
Safety
in_aqmust be a valid pointer.in_procmust be implemented correctly.in_user_datamust be a valid pointer or null.