pub unsafe extern "C-unwind" fn AudioQueueSetOfflineRenderFormat(
in_aq: AudioQueueRef,
in_format: *const AudioStreamBasicDescription,
in_layout: *const AudioChannelLayout,
) -> i32AudioQueue and objc2-core-audio-types only.Expand description
Specify an audio format to which the queue will perform subsequent offline rendering, or disable offline rendering.
An output queue’s audio playback can be redirected for capture to an audio file, to support an export function, for example. AudioQueueSetOfflineRenderFormat switches a queue between normal and offline rendering modes.
Parameter inAQ: The output queue whose offline rendering mode is to be changed.
Parameter inFormat: The desired format for offline rendering. Pass NULL to disable offline rendering and return the
queue to normal output to an audio device. This format must be linear PCM and (if not mono)
interleaved.
Parameter inLayout: The desired channel layout for offline rendering; also NULL when disabling offline rendering.
Returns: An OSStatus result code.
Safety
in_aqmust be a valid pointer.in_formatmust be a valid pointer or null.in_layoutmust be a valid pointer or null.