pub unsafe extern "C-unwind" fn AudioQueueStart(
in_aq: AudioQueueRef,
in_start_time: *const AudioTimeStamp,
) -> i32Available on crate features
AudioQueue and objc2-core-audio-types only.Expand description
Begins playing or recording audio.
If the audio hardware is not already running, this function starts it.
Parameter inAQ: The audio queue to start.
Parameter inStartTime: A pointer to the time at which the audio queue should start. If you specify the time
using the mSampleTime field of the AudioTimeStamp structure, the sample time is
referenced to the sample frame timeline of the associated audio device. May be NULL.
Returns: An OSStatus result code.
Safety
in_aqmust be a valid pointer.in_start_timemust be a valid pointer or null.