pub unsafe extern "C-unwind" fn AudioServicesAddSystemSoundCompletion(
in_system_sound_id: SystemSoundID,
in_run_loop: Option<&CFRunLoop>,
in_run_loop_mode: Option<&CFString>,
in_completion_routine: AudioServicesSystemSoundCompletionProc,
in_client_data: *mut c_void,
) -> i32AudioServices and objc2-core-foundation only.Expand description
This function will be deprecated in a future release. Use AudioServicesPlayAlertSoundWithCompletion or AudioServicesPlaySystemSoundWithCompletion instead.
Call the provided Completion Routine when provided SystemSoundID finishes playing.
Once set, the System Sound server will send a message to the System Sound client indicating which SystemSoundID has finished playing.
Parameter inSystemSoundID: The SystemSoundID to associate with the provided completion
routine.
Parameter inRunLoop: A CFRunLoopRef indicating the desired run loop the completion routine should
be run on. Pass NULL to use the main run loop.
Parameter inRunLoopMode: A CFStringRef indicating the run loop mode for the runloop where the
completion routine will be executed. Pass NULL to use kCFRunLoopDefaultMode.
Parameter inCompletionRoutine: An AudioServicesSystemSoundCompletionProc to be called when the provided
SystemSoundID has completed playing in the server.
Parameter inClientData: A void* to pass client data to the completion routine.
Safety
in_run_looppossibly has additional threading requirements.in_completion_routinemust be implemented correctly.in_client_datamust be a valid pointer or null.