pub unsafe extern "C-unwind" fn AudioServicesDisposeSystemSoundID(
in_system_sound_id: SystemSoundID,
) -> i32Available on crate feature
AudioServices only.Expand description
Allows the System Sound server to dispose any resources needed for the provided SystemSoundID.
Allows the application to tell the System Sound server that the resources for the associated audio file are no longer required.
Parameter inSystemSoundID: A SystemSoundID that the application no longer needs to use.