pub unsafe extern "C-unwind" fn AudioServicesPlayAlertSoundWithDetails(
in_system_sound_id: SystemSoundID,
in_details: Option<&CFDictionary>,
in_completion_block: Option<&DynBlock<dyn Fn()>>,
)Available on crate features
AudioServices and block2 and objc2-core-foundation only.Expand description
Play the alert designated by the provided SystemSoundID.
Parameter inSystemSoundID: A SystemSoundID for the system sound server to play with alert sound behavior.
Parameter inDetails: A set of details as described above.
Parameter inCompletionBlock: The completion block gets executed for every attempt to play a system sound irrespective
of success or failure. The callbacks are issued on a serial queue and the client is
responsible for handling thread safety.
Safety
in_details generics must be of the correct type.