pub unsafe extern "C-unwind" fn AudioServicesPlaySystemSound(
in_system_sound_id: SystemSoundID,
)Available on crate feature
AudioServices only.Expand description
This function will be deprecated in a future release. Use AudioServicesPlaySystemSoundWithCompletion instead.
Play the sound designated by the provided SystemSoundID.
A SystemSoundID indicating the desired System Sound to be played.
Parameter inSystemSoundID: A SystemSoundID for the System Sound server to play.