pub unsafe extern "C-unwind" fn AudioServicesRemoveSystemSoundCompletion(
in_system_sound_id: SystemSoundID,
)Available on crate feature
AudioServices only.Expand description
This function will be deprecated in a future release. Use AudioServicesPlayAlertSoundWithCompletion or AudioServicesPlaySystemSoundWithCompletion instead.
Disassociate any completion proc for the specified SystemSoundID
Tells the SystemSound client to remove any completion proc associated with the provided SystemSoundID
Parameter inSystemSoundID: The SystemSoundID for which completion routines should be
removed.