pub unsafe extern "C-unwind" fn AudioSessionAddPropertyListener(
in_id: AudioSessionPropertyID,
in_proc: AudioSessionPropertyListener,
in_client_data: *mut c_void,
) -> i32๐Deprecated: no longer supported
Available on crate feature
AudioSession only.Expand description
Add a property listener.
This function can be used to add a listener to be called when a property changes. If a listener and user data already exist for this property, they will be replaced. Valid properties are listed above.
Parameter inID: The AudioSessionPropertyID for which we want to set a listener.
Parameter inProc: The listener to be called when the property changes.
Parameter inClientData: The client user data to use when calling the listener.
Returns: kAudioSessionNoError if the operation was successful. If the property does not support listeners, kAudioSessionUnsupportedPropertyError will be returned. Other error codes listed under AudioSession Error Constants also apply to this function.
Safety
in_procmust be implemented correctly.in_client_datamust be a valid pointer.