pub unsafe extern "C-unwind" fn AudioSessionGetPropertySize(
in_id: AudioSessionPropertyID,
out_data_size: *mut u32,
) -> i32๐Deprecated: no longer supported
Available on crate feature
AudioSession only.Expand description
Get the size of the payload for a property.
This function can be called to get the size for the payload of a property. Valid properties are listed in an enum above.
Parameter inID: The AudioSessionPropertyID for which we want to get the size of the payload.
Parameter outDataSize: The size of the data payload will be copied here.
Safety
out_data_size must be a valid pointer.