pub unsafe extern "C-unwind" fn AudioUnitExtensionCopyComponentList(
extension_identifier: &CFString,
) -> Option<CFRetained<CFArray>>Available on crate features
AUComponent and objc2-core-foundation only.Expand description
Returns the component registrations for a given audio unit extension.
Parameter extensionIdentifier: The bundle ID of the audio unit extension.
Returns: An array of dictionaries, one for each component, in the same format as described in AudioComponent.h for the Info.plist key “AudioComponents”. The caller should release this value when done with it.