pub unsafe extern "C-unwind" fn AudioUnitGetProperty(
in_unit: AudioUnit,
in_id: AudioUnitPropertyID,
in_scope: AudioUnitScope,
in_element: AudioUnitElement,
out_data: NonNull<c_void>,
io_data_size: NonNull<u32>,
) -> i32Available on crate features
AUComponent and AudioComponent only.Expand description
retrieves the value of a specified property
The API can is used to retrieve the value of the property. Property values for audio units are always passed by reference
Parameter inUnit: the audio unit
Parameter inID: the property identifier
Parameter inScope: the scope of the property
Parameter inElement: the element of the scope
Parameter outData: used to retrieve the value of the property. It should point to memory at least
as large as the value described by ioDataSize
Parameter ioDataSize: on input contains the size of the data pointed to by outData, on output, the
size of the data that was returned.
Returns: noErr, or various audio unit errors related to properties
Safety
in_unitmust be a valid pointer.out_datamust be a valid pointer.io_data_sizemust be a valid pointer.