pub unsafe extern "C-unwind" fn AudioUnitInitialize(
in_unit: AudioUnit,
) -> i32Available on crate features
AUComponent and AudioComponent only.Expand description
initialize an audio unit
Upon success, the audio unit has been successfully initialized. This means that the formats for input and output are valid and can be supported and it has based its allocations on the max number of frames that it is able to render at any given time. Once initialized, it is in a state where it can be asked to render.
In common practice, major state of an audio unit (such as its I/O formats, memory allocations) cannot be changed while an audio unit is initialized.
Parameter inUnit: The audio unit to initialize
Returns: noErr, or an error representing the reasons why the audio unit was not able to be initialized successfully
Safety
in_unit must be a valid pointer.