pub unsafe extern "C-unwind" fn AudioUnitSetProperty(
in_unit: AudioUnit,
in_id: AudioUnitPropertyID,
in_scope: AudioUnitScope,
in_element: AudioUnitElement,
in_data: *const c_void,
in_data_size: u32,
) -> i32AUComponent and AudioComponent only.Expand description
sets the value of a specified property
The API can is used to set the value of the property. Property values for audio units are always passed by reference
Parameter inUnit: the audio unit
Parameter inID: the property identifier
Parameter inScope: the scope of the property
Parameter inElement: the element of the scope
Parameter inData: if not null, then is the new value for the property that will be set. If null,
then inDataSize should be zero, and the call is then used to remove a
previously set value for a property. This removal is only valid for
some properties, as most properties will always have a default value if not
set.
Parameter inDataSize: the size of the data being provided in inData
Returns: noErr, or various audio unit errors related to properties
Safety
in_unitmust be a valid pointer.in_datamust be a valid pointer or null.