pub unsafe extern "C-unwind" fn AudioUnitUninitialize(
in_unit: AudioUnit,
) -> i32AUComponent and AudioComponent only.Expand description
uninitialize an audio unit
Once an audio unit has been initialized, to change its state in response to some kind of environmental change, the audio unit should be uninitialized. This will have the effect of the audio unit de-allocating its resources. The caller can then reconfigure the audio unit to match the new environment (for instance, the sample rate to process audio is different than it was) and then re-initialize the audio unit when those changes have been applied.
Parameter inUnit: The audio unit to uninitialize
Returns: noErr, or an error representing the reasons why the audio unit was not able to be initialized successfully. Typically this call won’t return an error unless the audio unit in question is no longer valid.
Safety
in_unit must be a valid pointer.