pub unsafe extern "C-unwind" fn CAClockGetPlayRate(
in_ca_clock: CAClockRef,
out_play_rate: NonNull<f64>,
) -> i32Expand description
Obtain the clock’s playback rate.
Returns the clock’s current play rate. If the clock is internally synced, this will be the last rate set by CAClockSetPlayRate. If the clock is externally synced, it will be the rate of the external sync source, where 1.0 means that it is running at exactly the same rate as the clock’s timebase. (2.0 means twice as fast).
Parameter inCAClock: The clock object.
Parameter outPlayRate: On exit, the clock’s playback rate.
Returns: An OSStatus error code.
Safety
in_ca_clockmust be a valid pointer.out_play_ratemust be a valid pointer.