pub unsafe extern "C-unwind" fn CopyNameFromSoundBank(
in_url: &CFURL,
out_name: NonNull<*const CFString>,
) -> i32Available on crate feature
objc2-core-foundation only.Expand description
This will return the name of a sound bank from a DLS or SF2 bank. The name should be released by the caller.
Parameter inURL: The URL for the sound bank.
Parameter outName: A pointer to a CFStringRef to be created and returned by the function.
Returns: returns noErr if successful.
Safety
out_name must be a valid pointer.