pub unsafe extern "C-unwind" fn MusicEventIteratorSetEventTime(
in_iterator: MusicEventIterator,
in_time_stamp: MusicTimeStamp,
) -> i32Available on crate feature
MusicPlayer only.Expand description
Set a new time for an event
The iterator will still be pointing to the same event, but as the event will have moved, it may or may not have a next or previous event now (depending of course on the time you moved it to).
Parameter inIterator: the iterator
Parameter inTimeStamp: the new time stamp of the event
Safety
in_iterator must be a valid pointer.