pub unsafe extern "C-unwind" fn MusicPlayerSetSequence(
in_player: MusicPlayer,
in_sequence: MusicSequence,
) -> i32Available on crate feature
MusicPlayer only.Expand description
Set the sequence for the player to play
A Sequence cannot be set on a player while it is playing. Setting a sequence will overide the currently set sequence.
Parameter inPlayer: the player
Parameter inSequence: the sequence for the player to play
Safety
in_playermust be a valid pointer.in_sequencemust be a valid pointer or null.