pub unsafe extern "C-unwind" fn MusicSequenceFileLoad(
in_sequence: MusicSequence,
in_file_ref: &CFURL,
in_file_type_hint: MusicSequenceFileTypeID,
in_flags: MusicSequenceLoadFlags,
) -> i32Available on crate features
MusicPlayer and objc2-core-foundation only.Expand description
Load the data contained within the referenced file to the sequence
This function will parse the file referenced by the URL and add the events to the sequence.
Parameter inSequence: the sequence
Parameter inFileRef: a file:// URL that references a file
Parameter inFileTypeHint: provides a hint to the sequence on the file type being imported. Can be zero in many cases.
Parameter inFlags: flags that can control how the data is parsed in the file and laid out in the tracks
that will be created and added to the sequence in this operation
Safety
in_sequence must be a valid pointer.