pub unsafe extern "C-unwind" fn MusicSequenceFileLoadData(
in_sequence: MusicSequence,
in_data: &CFData,
in_file_type_hint: MusicSequenceFileTypeID,
in_flags: MusicSequenceLoadFlags,
) -> i32Available on crate features
MusicPlayer and objc2-core-foundation only.Expand description
Load the data to the sequence
This function will parse the data and add the events to the sequence. The data provided needs to be of a particular file type as specified by the fileTypeHint.
Parameter inSequence: the sequence
Parameter inData: the contents of a valid file loaded into a CFData object
Parameter inFileTypeHint: provides a hint to the sequence on the file type being imported. Can be zero in many cases.
Parameter inFlags: flags that can control how the data is parsed in the file and laid out in the tracks
that will be created and added to the sequence in this operation
Safety
in_sequence must be a valid pointer.