pub unsafe extern "C-unwind" fn MusicTrackCopyInsert(
in_source_track: MusicTrack,
in_source_start_time: MusicTimeStamp,
in_source_end_time: MusicTimeStamp,
in_dest_track: MusicTrack,
in_dest_insert_time: MusicTimeStamp,
) -> i32Available on crate feature
MusicPlayer only.Expand description
Copies events from one track and inserts them into another
Copies all of the events with the specified time range of the source track. It then inserts those events into the destination track. All events at and after inDestInsertTime in inDestTrack are moved forward by the range’s duration
All time ranges are [starttime < endtime]
Parameter inSourceTrack: the source track
Parameter inSourceStartTime: the start time for the range of events
Parameter inSourceEndTime: the end time up to which will form the range of the events to copy from the source track
Parameter inDestTrack: the destination track to copy too
Parameter inDestInsertTime: the time at which the copied events will be inserted.
Safety
in_source_trackmust be a valid pointer.in_dest_trackmust be a valid pointer.