pub unsafe extern "C-unwind" fn MusicTrackCut(
in_track: MusicTrack,
in_start_time: MusicTimeStamp,
in_end_time: MusicTimeStamp,
) -> i32Available on crate feature
MusicPlayer only.Expand description
Removes all the events within the specified range
Events that fall past the specified range will be moved back by the specified range time.
All time ranges are [starttime < endtime]
Parameter inTrack: the track
Parameter inStartTime: the start time for the range of events
Parameter inEndTime: the end time up to which will form the range of the events to cut out
Safety
in_track must be a valid pointer.