pub unsafe extern "C-unwind" fn MusicTrackMoveEvents(
in_track: MusicTrack,
in_start_time: MusicTimeStamp,
in_end_time: MusicTimeStamp,
in_move_time: MusicTimeStamp,
) -> i32Available on crate feature
MusicPlayer only.Expand description
Move events in a track
Moves all of the events in the specified time range by the moveTime. MoveTime maybe negative to move events backwards (towards zero).
All time ranges are [starttime < endtime]
Parameter inTrack: the track
Parameter inStartTime: the start time for the range of events
Parameter inEndTime: the end time up to which will form the range of the events to move
Parameter inMoveTime: amount of beats to move the selected events.
Safety
in_track must be a valid pointer.