pub unsafe extern "C-unwind" fn MusicTrackNewExtendedNoteEvent(
in_track: MusicTrack,
in_time_stamp: MusicTimeStamp,
in_info: NonNull<ExtendedNoteOnEvent>,
) -> i32Available on crate features
AUComponent and MusicDevice and MusicPlayer only.Expand description
Adds a ExtendedNoteOnEvent to a track
The event is added at the specified time stamp. The time stamp should not be less than zero.
Parameter inTrack: the track
Parameter inTimeStamp: the time stamp
Parameter inInfo: the event
Safety
in_trackmust be a valid pointer.in_infomust be a valid pointer.