pub unsafe extern "C-unwind" fn MusicTrackSetDestNode(
in_track: MusicTrack,
in_node: AUNode,
) -> i32Available on crate features
AUGraph and MusicPlayer only.Expand description
Sets the track’s target to the specified AUNode
The node must be a member of the graph that the track’s sequence is using. When played, the track will send all of its events to that node.
Parameter inTrack: the track
Parameter inNode: the new node
Safety
in_track must be a valid pointer.