#[repr(C)]pub struct AudioUnitMeterClipping {
pub peakValueSinceLastCall: f32,
pub sawInfinity: u8,
pub sawNotANumber: u8,
}Available on crate feature
AudioUnitProperties only.Expand description
The maximum value seen on the channel since the last time the property was retrieved.
TRUE if there was an infinite value on this channel.
TRUE if there was a floating point Not-A-Number value on this channel.
See also Apple’s documentation
Fields
peakValueSinceLastCall: f32sawInfinity: u8sawNotANumber: u8Trait Implementations
Sourceimpl Clone for AudioUnitMeterClipping
impl Clone for AudioUnitMeterClipping
Sourcefn clone(&self) -> AudioUnitMeterClipping
fn clone(&self) -> AudioUnitMeterClipping
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AudioUnitMeterClipping
impl Debug for AudioUnitMeterClipping
Sourceimpl Encode for AudioUnitMeterClipping
impl Encode for AudioUnitMeterClipping
Sourceimpl PartialEq for AudioUnitMeterClipping
impl PartialEq for AudioUnitMeterClipping
Sourceimpl RefEncode for AudioUnitMeterClipping
impl RefEncode for AudioUnitMeterClipping
Sourceconst ENCODING_REF: Encoding
const ENCODING_REF: Encoding
The Objective-C type-encoding for a reference of this type. Read more
impl Copy for AudioUnitMeterClipping
impl StructuralPartialEq for AudioUnitMeterClipping