pub type AUMIDICIProfileChangedBlock = *mut DynBlock<dyn Fn(u8, MIDIChannelNumber, NonNull<MIDICIProfile>, Bool)>;Available on crate features
AUAudioUnit and block2 and objc2-core-midi only.Expand description
Block by which hosts are informed of an audio unit having enabled or disabled a MIDI-CI profile.
Parameter cable: The virtual MIDI cable on which the event occured.
Parameter channel: The MIDI channel on which the profile was enabled or disabled.
Parameter profile: The MIDI-CI profile.
Parameter enabled: YES if the profile was enabled, NO if the profile was disabled.
See also Appleās documentation