pub type AUScheduleMIDIEventBlock = *mut DynBlock<dyn Fn(AUEventSampleTime, u8, NSInteger, NonNull<u8>)>;Available on crate features
AUAudioUnit and AudioUnitProperties and block2 only.Expand description
Block to schedule MIDI events.
Parameter eventSampleTime: The sample time (timestamp->mSampleTime) at which the MIDI event is to occur. When
scheduling events during the render cycle (e.g. via a render observer) this time can be
AUEventSampleTimeImmediate plus an optional buffer offset, in which case the event is
scheduled at that position in the current render cycle.
Parameter cable: The virtual cable number.
Parameter length: The number of bytes of MIDI data in the provided event(s).
Parameter midiBytes: One or more valid MIDI 1.0 events, except sysex which must always be sent as the only event
in the chunk. Also, running status is not allowed.
See also Appleās documentation