pub type AUScheduleParameterBlock = *mut DynBlock<dyn Fn(AUEventSampleTime, AUAudioFrameCount, AUParameterAddress, AUValue)>;AUAudioUnit and AUParameters and AudioUnitProperties and block2 only.Expand description
Block to schedule parameter changes.
Not all parameters are rampable; check the parameter’s flags. Note: If the parameter is not rampable, a rampDuration of zero will result in an immediate change to the target value, however, if rampDuration is non-zero, the parameter will not change.
Parameter eventSampleTime: The sample time (timestamp->mSampleTime) at which the parameter is to begin changing. When
scheduling parameters during the render cycle (e.g. via a render observer) this time can be
AUEventSampleTimeImmediate plus an optional buffer offset, in which case the event is
scheduled at that position in the current render cycle.
Parameter rampDurationSampleFrames: The number of sample frames over which the parameter’s value is to ramp, or 0 if the
parameter change should take effect immediately.
Parameter parameterAddress: The parameter’s address.
Parameter value: The parameter’s new value if the ramp duration is 0; otherwise, the value at the end
of the scheduled ramp.
See also Apple’s documentation