pub type AudioComponentMethod = Option<unsafe extern "C-unwind" fn(NonNull<c_void>, ...) -> i32>;Available on crate feature
AudioComponent only.Expand description
Generic prototype for an audio plugin method.
Every audio plugin will implement a collection of methods that match a particular selector. For example, the AudioUnitInitialize API call is implemented by a plugin implementing the kAudioUnitInitializeSelect selector. Any function implementing an audio plugin selector conforms to the basic pattern where the first argument is a pointer to the plugin instance structure, has 0 or more specific arguments, and returns an OSStatus.
See also Apple’s documentation
Aliased Type
pub enum AudioComponentMethod {
None,
Some(unsafe extern "C-unwind" fn(NonNull<c_void>, ...) -> i32),
}