pub type AudioUnitRenderProc = Option<unsafe extern "C-unwind" fn(NonNull<c_void>, *mut AudioUnitRenderActionFlags, NonNull<AudioTimeStamp>, u32, u32, NonNull<AudioBufferList>) -> i32>;Available on crate features
AUComponent and objc2-core-audio-types only.Expand description
This proc can be exported through the FastDispatch property or is used as the prototype for an audio component dispatch for this selector.
The arguments are the same as are provided to the corresponding API call
Parameter inComponentStorage: For a component manager component, this is the component instance storage
pointer
See also Apple’s documentation
Aliased Type
pub enum AudioUnitRenderProc {
None,
Some(unsafe extern "C-unwind" fn(NonNull<c_void>, *mut AudioUnitRenderActionFlags, NonNull<AudioTimeStamp>, u32, u32, NonNull<AudioBufferList>) -> i32),
}Variants
None
No value.
Some(unsafe extern "C-unwind" fn(NonNull<c_void>, *mut AudioUnitRenderActionFlags, NonNull<AudioTimeStamp>, u32, u32, NonNull<AudioBufferList>) -> i32)
Some value of type T.