pub type MusicDeviceStopNoteProc = Option<unsafe extern "C-unwind" fn(NonNull<c_void>, MusicDeviceGroupID, NoteInstanceID, u32) -> i32>;Available on crate feature
MusicDevice only.Expand description
This proc can be exported through the FastDispatch property or is used as the prototype for an audio component dispatch for this selector.
The arguments are the same as are provided to the corresponding API call
Parameter self: For a component manager component, this is the component instance storage pointer
Returns: noErr, or an audio unit error code
See also Apple’s documentation
Aliased Type
pub enum MusicDeviceStopNoteProc {
None,
Some(unsafe extern "C-unwind" fn(NonNull<c_void>, u32, u32, u32) -> i32),
}